@@ -3,14 +3,14 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2010                                                *
+ *  Copyright (c) 2001-2011                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 /**
  * Retour d'authentification pour les SSO
@@ -31,7 +31,7 @@ function action_auth_dist() {
 
 		if (is_string($res)){ // Erreur
 			$redirect = _request('redirect');
-			$redirect = parametre_url($redirect,'var_erreur',$res);
+			$redirect = parametre_url($redirect,'var_erreur',$res,'&');
 			include_spip('inc/headers');
 			redirige_par_entete($redirect);
 		}
@@ -42,4 +42,4 @@ function action_auth_dist() {
 }
 
 
-?>
\ No newline at end of file
+?>
