@@ -3,14 +3,14 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2010                                                *
+ *  Copyright (c) 2001-2011                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined("_ECRIRE_INC_VERSION")) return;	#securite
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 include_spip('base/abstract_sql');
 include_spip('inc/filtres');
@@ -24,13 +24,13 @@ function balise_FORMULAIRE_INSCRIPTION ($p) {
 }
 
 // args[0] un statut d'auteur (redacteur par defaut)
-// args[1] indique la rubrique eventuelle de proposition
-// args[2] indique le focus eventuel
+// args[1] indique le focus eventuel
+// args[2] indique la rubrique eventuelle de proposition
 // [(#FORMULAIRE_INSCRIPTION{nom_inscription, #ID_RUBRIQUE})]
 
 // http://doc.spip.org/@balise_FORMULAIRE_INSCRIPTION_stat
 function balise_FORMULAIRE_INSCRIPTION_stat($args, $context_compil) {
-	list($mode, $id, $focus) = $args;
+	list($mode, $focus, $id) = $args;
 	$mode = tester_config($id, $mode);
 	return $mode ? array($mode, $focus, $id) : '';
 }
