@@ -3,14 +3,14 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2010                                                *
+ *  Copyright (c) 2001-2011                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 //
 // Utilitaires indispensables autour des serveurs SQL
@@ -60,7 +60,11 @@ function spip_connect($serveur='', $version='') {
 		if (!isset($GLOBALS['db_ok'])) {
 		  // fera mieux la prochaine fois
 			if ($install) return false;
-			spip_log("spip_connect: serveur $index mal defini dans '$f'.");
+			if ($f AND $readable)
+				spip_log("spip_connect: fichier de connexion '$f' OK.");
+			else
+				spip_log("spip_connect: fichier de connexion '$f' non trouve");
+			spip_log("spip_connect: echec connexion ou serveur $index mal defini dans '$f'.");
 			// ne plus reessayer si ce n'est pas l'install
 			return $connexions[$index]=false;
 		}
@@ -155,6 +159,7 @@ function spip_connect_db($host, $port, $login, $pass, $db='', $type='mysql', $pr
 	if (@file_exists($f)
 	AND (time() - @filemtime($f) < 30)
 	AND !defined('_ECRIRE_INSTALL')) {
+		spip_log("Echec : $f recent. Pas de tentative de connexion");
 		return;
 	}
 	if (!$prefixe)
@@ -179,9 +184,7 @@ function spip_connect_db($host, $port, $login, $pass, $db='', $type='mysql', $pr
 	// En cas d'indisponibilite du serveur, eviter de le bombarder
 	if (!defined('_ECRIRE_INSTALL')) {
 		@touch($f);
-		$err = "Echec connexion $host $port $login $db";
-		spip_log($err);
-		spip_log($err, $type);
+		spip_log("Echec connexion serveur $type : host[$host] port[$port] login[$login] base[$db]", $type);
 	}
 }
 
@@ -293,10 +296,19 @@ function id_table_objet($type,$serveur='') {
 
 // http://doc.spip.org/@objet_type
 function objet_type($table_objet){
+	static $surnoms = null;
+	if (!$surnoms){
+		// passer dans un pipeline qui permet aux plugins de declarer leurs exceptions
+		$surnoms = pipeline('declarer_type_surnoms', array());
+	}
+	
 	// scenario de base
 	// le type est decline a partir du nom de la table en enlevant le prefixe eventuel
 	// et la marque du pluriel
 	$type = preg_replace(',^spip_|s$,', '', $table_objet);
+	if (isset($surnoms[$type]))
+		return $surnoms[$type];
+
 	// si le type redonne bien la table c'est bon
 	if ( (table_objet($type)==$table_objet)
 	  OR (table_objet_sql($type)==$table_objet))
