@@ -3,14 +3,14 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2010                                                *
+ *  Copyright (c) 2001-2011                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 include_spip('inc/presentation');
 include_spip('inc/config');
@@ -26,8 +26,8 @@ function configuration_mots_dist(){
 	$config_precise_groupes = $GLOBALS['meta']["config_precise_groupes"];
 	$mots_cles_forums = $GLOBALS['meta']["mots_cles_forums"];
 	$forums_publics = $GLOBALS['meta']["forums_publics"]!='non';
-	if (!$forums_public){
-		$forums_public = sql_countsel('spip_forums', "statut='publie'");
+	if (!$forums_publics){
+		$forums_publics = sql_countsel('spip_forum', "statut='publie'");
 	}
 
 	$res .= "<table border='0' cellspacing='1' cellpadding='3' width=\"100%\">"
@@ -64,7 +64,7 @@ function configuration_mots_dist(){
 	. "</td></tr></table>"
 	. fin_cadre_relief(true);
 
-	if ($forums_publics != "non"){
+	if ($forums_publics){
 		$res .= "<br />\n"
 		. debut_cadre_relief("", true, "", _T('titre_mots_cles_dans_forum'))
 		. "<table border='0' cellspacing='1' cellpadding='3' width=\"100%\">"
