@@ -3,14 +3,14 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2010                                                *
+ *  Copyright (c) 2001-2011                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 include_spip('inc/presentation');
 
@@ -240,13 +240,8 @@ function exec_brouteur_frame_dist() {
 		}
 	}
    }
-	if (count($GLOBALS['tableau_des_temps'])) {
-		include_spip('public/debug');
-		echo chrono_requete($GLOBALS['tableau_des_temps']);
-	}
 	echo "</div>";
 
-
 	echo "</body></html>";
 }
 
