@@ -3,18 +3,23 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2010                                                *
+ *  Copyright (c) 2001-2011                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 // http://doc.spip.org/@exec_configurer_previsualiseur_dist
 function exec_configurer_previsualiseur_dist()
 {
+	if(!autoriser('configurer', _request('configuration'))) {
+		include_spip('inc/minipres');
+		echo minipres(_T('info_acces_interdit'));
+		exit;
+	}
 	$previsualiseur = charger_fonction('previsualiseur', 'configuration');
 	include_spip('inc/actions');
 	ajax_retour($previsualiseur());
