@@ -3,14 +3,14 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2010                                                *
+ *  Copyright (c) 2001-2011                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 include_spip('inc/presentation');
 
 // http://doc.spip.org/@exec_recherche_dist
@@ -101,6 +101,10 @@ function exec_recherche_dist() {
 				$titre = _T('titre_documents_joints');
 				$order = "id_$table";
 				break;
+			case 'groupes_mot':
+				$titre = _T('titre_groupe_mots');
+				$order = 'titre';
+				break;
 			default:
 				$titre = _T("autres");
 				$order = "id_$table";
@@ -110,9 +114,9 @@ function exec_recherche_dist() {
 			echo afficher_objets($table,$titre,
 				array(
 					// gasp: la requete spip_articles exige AS articles...
-					'FROM' => table_objet_sql($table).' AS '.$table.'s',
+					'FROM' => table_objet_sql($table).' AS '.table_objet($table),
 					'WHERE' => sql_in(
-						$table.'s.'.id_table_objet($table),
+						table_objet($table).'.'.id_table_objet($table),
 						array_keys($r)
 					),
 					'ORDER BY' => $order
