@@ -3,14 +3,14 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2010                                                *
+ *  Copyright (c) 2001-2011                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 include_spip('inc/presentation');
 include_spip('inc/date');
 include_spip('inc/config');
@@ -213,7 +213,7 @@ function options_moderation($row) {
 
 	global $spip_lang_left;
 
-	if ($row['syndication'] == 'non') return '';
+	if ($row['syndication'] == 'non' or $row['syndication'] == '') return '';
 
 	$id_syndic = $row['id_syndic'];
 	$moderation = $row['moderation'];
