@@ -3,14 +3,14 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2010                                                *
+ *  Copyright (c) 2001-2011                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 
 // http://doc.spip.org/@generer_action_auteur
@@ -108,7 +108,7 @@ function ajax_action_auteur($action, $id, $script, $args='', $corps=false, $args
 // Comme ci-dessus, mais reduit au cas POST et on fournit le bouton Submit.
 // 
 // http://doc.spip.org/@ajax_action_post
-function ajax_action_post($action, $arg, $retour, $gra, $corps, $clic='', $atts_i='', $atts_span = "", $args_ajax='')
+function ajax_action_post($action, $arg, $retour, $gra, $corps, $clic='', $atts_i='', $atts_span = "", $args_ajax='', $fct_ajax='')
 {
 	global $spip_lang_right;
 
@@ -152,12 +152,13 @@ function ajax_action_post($action, $arg, $retour, $gra, $corps, $clic='', $atts_
 		if (isset($GLOBALS['var_profile']))
 			$args_ajax .= '&var_profile=1';
 
+		$js = ajax_action_declencheur('this', $ancre, $fct_ajax);
 		return redirige_action_post($action,
 			$arg,
 			$action,
 			"script=$retour$args_ajax",
 			$corps,
-			" onsubmit=" . ajax_action_declencheur('this', $ancre));
+			" onsubmit=$js");
 	}
 }
 
@@ -194,24 +195,24 @@ function ajax_action_greffe($fonction, $id, $corps)
 }
 
 // http://doc.spip.org/@ajax_retour
-function ajax_retour($corps,$xml = true)
+function ajax_retour($corps, $xml = true)
 {
-	if (isset($_COOKIE['spip_admin'])
-	AND ((_request('var_mode') == 'debug') OR !empty($GLOBALS['tableau_des_temps'])))
+	if (isset($_COOKIE['spip_admin']) AND $GLOBALS['tableau_des_temps'])
 		erreur_squelette();
-	else {
-		if (isset($GLOBALS['transformer_xml']) OR $GLOBALS['exec'] == 'valider_xml') {
-	 	$debut = _DOCTYPE_ECRIRE
-		. "<html><head><title>Debug Spip Ajax</title></head>"
-		.  "<body><div>\n\n"
-		. "<!-- %%%%%%%%%%%%%%%%%%% Ajax %%%%%%%%%%%%%%%%%%% -->\n";
+	else { 
+		if ($GLOBALS['exec'] == 'valider_xml') {
+		 	$debut = _DOCTYPE_ECRIRE
+			. "<html><head><title>Debug Spip Ajax</title></head>"
+			.  "<body><div>\n\n"
+			. "<!-- %%%%%%%%%%%%%%%%%%% Ajax %%%%%%%%%%%%%%%%%%% -->\n";
 
-		$fin = '</div></body></html>';
+			$fin = '</div></body></html>';
 
 		} else {
 			$c = $GLOBALS['meta']["charset"];
 			header('Content-Type: text/html; charset='. $c);
 			$debut = (($xml AND strlen(trim($corps)))?'<' . "?xml version='1.0' encoding='" . $c . "'?" . ">\n":'');
+			$fin = '';
 		}
 		echo $debut, $corps, $fin;
 	}
@@ -219,7 +220,8 @@ function ajax_retour($corps,$xml = true)
 
 // http://doc.spip.org/@determine_upload
 function determine_upload($type='') {
-
+	include_spip('inc/autoriser');
+	
 	if (!autoriser('chargerftp')
 	OR $type == 'logos') # on ne le permet pas pour les logos
 		return false;
