@@ -3,14 +3,14 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2010                                                *
+ *  Copyright (c) 2001-2011                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 include_spip('inc/getdocument');
 include_spip('inc/documents');
@@ -55,7 +55,7 @@ function inc_choisir_mode_document_dist($fichier, $type_lien, $type_image, $larg
 	// il suffit de faire dans mes_options
 	// define('_LARGEUR_MODE_IMAGE', 450);
 	// pour beneficier de cette detection auto
-	@define('_LARGEUR_MODE_IMAGE', 0);
+	if (!defined('_LARGEUR_MODE_IMAGE')) define('_LARGEUR_MODE_IMAGE', 0);
 	
 	if (!_LARGEUR_MODE_IMAGE)
 		return 'image';
@@ -186,8 +186,6 @@ function ajouter_un_document($source, $nom_envoye, $type_lien, $id_lien, $mode,
 			spip_log ("Echec copie du fichier $fichier");
 			return;
 		}
-
-
 		
 		// _INTERFACE_DOCUMENTS
 		// Si mode == 'choix', fixer le mode image/document
@@ -289,8 +287,28 @@ function ajouter_un_document($source, $nom_envoye, $type_lien, $id_lien, $mode,
 	// note : la fonction peut "mettre a jour un document" si on lui
 	// passe "mode=document" et "id_document=.." (pas utilise)
 
+		// Envoyer aux plugins
+		$a = pipeline('pre_insertion',
+			array(
+				'args' => array(
+					'table' => 'spip_documents',
+				),
+				'data' => $a
+			)
+		);
+
 		$id = sql_insertq("spip_documents", $a);
 
+		pipeline('post_insertion',
+			array(
+				'args' => array(
+					'table' => 'spip_documents',
+					'id_objet' => $id_document
+				),
+				'data' => $a
+			)
+		);
+
 		spip_log ("ajout du document $source $nom_envoye  (M '$mode' T '$type_lien' L '$id_lien' D '$id')");
 
 		if ($id_lien AND $id
@@ -390,7 +408,7 @@ function traite_svg($file)
 	// Securite si pas admin : virer les scripts et les references externes
 	// sauf si on est en mode javascript 'ok' (1), cf. inc_version
 	if ($GLOBALS['filtrer_javascript'] < 1
-	AND $GLOBALS['visiteur_session']['statut'] != '0minirezo') {
+	AND !autoriser('televerser','script')) {
 		include_spip('inc/texte');
 		$new = trim(safehtml($texte));
 		// petit bug safehtml
@@ -438,6 +456,8 @@ function corriger_extension($ext) {
 		return 'jpg';
 	case 'tiff':
 		return 'tif';
+	case 'mpeg':
+		return 'mpg';
 	default:
 		return $ext;
 	}
