@@ -3,14 +3,14 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2010                                                *
+ *  Copyright (c) 2001-2011                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 include_spip('base/abstract_sql');
 //
@@ -465,11 +465,12 @@ function auth_terminer_identifier_login($auth_methode, $login, $serveur=''){
 	$session = charger_fonction('session', 'inc');
 	$session($auteur);
 	$p = ($auteur['prefs']) ? unserialize($auteur['prefs']) : array();
-	$p['cnx'] = ($session_remember == 'oui') ? 'perma' : '';
+	$p['cnx'] = ($auteur['cookie'] == 'oui') ? 'perma' : '';
 	$p = array('prefs' => serialize($p));
 	sql_updateq('spip_auteurs', $p, "id_auteur=" . $auteur['id_auteur']);
 
 	if ($auteur['statut'] == 'nouveau') {
+		$session(); // charger la session car on va la modifier
 		$auteur['statut'] = acces_statut($auteur['id_auteur'], $auteur['statut'], $auteur['bio']);
 	}
 
@@ -622,11 +623,15 @@ function auth_synchroniser_distant($auth_methode=true, $id_auteur=0, $champs=arr
  * @return array
  */
 function lire_php_auth($login, $pw, $serveur=''){
-	// en auth php, le login est forcement celui en base
-	// pas la peine de passer par la methode auth/xxx pour identifier le login
-	$row = sql_fetsel('*', 'spip_auteurs', 'login=' . sql_quote($login),'','','','',$serveur);
-	if (!$row) return false; // n'existe pas
 
+	$row = sql_fetsel('*', 'spip_auteurs', 'login=' . sql_quote($login),'','','','',$serveur);
+
+	if (!$row) {
+		if (spip_connect_ldap($serveur)
+		AND $auth_ldap = charger_fonction('ldap', 'auth', true))
+			return $auth_ldap($login, $pw, $serveur);
+		return false;
+	}
 	// su pas de source definie
 	// ou auth/xxx introuvable, utiliser 'spip'
 	if (!$auth_methode = $row['source']
@@ -665,4 +670,4 @@ function ask_php_auth($pb, $raison, $retour, $url='', $re='', $lien='') {
 		echo " [<a href='$ici'>"._T('login_espace_prive')."</a>]";
 	exit;
 }
-?>
\ No newline at end of file
+?>
