@@ -3,14 +3,14 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2010                                                *
+ *  Copyright (c) 2001-2011                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 include_spip('base/abstract_sql');
 
@@ -489,13 +489,19 @@ function autoriser_sauvegarder_dist($faire, $type, $id, $qui, $opt) {
 }
 
 // Effacer la base de donnees ?
-// admins seulement (+auth ftp)
-// a transformer en webmestre quand la notion sera fixee
+// webmestres seulement
 // http://doc.spip.org/@autoriser_detruire_dist
 function autoriser_detruire_dist($faire, $type, $id, $qui, $opt) {
+	return
+		autoriser('webmestre', null, null, $qui, $opt);
+}
+
+// Consulter le forum des admins ?
+// admins y compris restreints
+// http://doc.spip.org/@autoriser_forum_admin_dist
+function autoriser_forum_admin_dist($faire, $type, $id, $qui, $opt) {
 	return
 		$qui['statut'] == '0minirezo'
-		AND !$qui['restreint']
 		;
 }
 
@@ -672,16 +678,15 @@ function autoriser_modifierurl_dist($faire, $quoi, $id, $qui, $opt) {
 
 // http://doc.spip.org/@autoriser_rubrique_editermots_dist
 function autoriser_rubrique_editermots_dist($faire,$quoi,$id,$qui,$opts){
-	// on verifie que le champ de droit passe en opts colle bien
+	// on recupere les champs du groupe s'ils ne sont pas passes en opt
 	$droit = substr($GLOBALS['visiteur_session']['statut'],1);
-	if (!isset($opts['groupe_champs'][$droit])){
+	if (!isset($opts['groupe_champs'])){
 		if (!$id_groupe = $opts['id_groupe'])
 			return false;
 		include_spip('base/abstract_sql');
-		$droit = sql_getfetsel($droit, "spip_groupes_mots", "id_groupe=".intval($id_groupe));
+		$opts['groupe_champs'] = sql_fetsel("*", "spip_groupes_mots", "id_groupe=".intval($id_groupe));
 	}
-	else
-		$droit = $opts['groupe_champs'][$droit];
+	$droit = $opts['groupe_champs'][$droit];
 
 	return
 		($droit == 'oui')
@@ -705,6 +710,38 @@ function autoriser_syndic_editermots_dist($faire,$quoi,$id,$qui,$opts){
 	return autoriser_rubrique_editermots_dist($faire,'syndic',0,$qui,$opts);
 }
 
+// http://doc.spip.org/@autoriser_rubrique_iconifier_dist
+function autoriser_rubrique_iconifier_dist($faire,$quoi,$id,$qui,$opts){
+	return autoriser('publierdans', 'rubrique', $id, $qui, $opt);
+}
+// http://doc.spip.org/@autoriser_auteur_iconifier_dist
+function autoriser_auteur_iconifier_dist($faire,$quoi,$id,$qui,$opts){
+ return (($id == $qui['id_auteur']) OR
+ 		(($qui['statut'] == '0minirezo') AND !$qui['restreint']));
+}
+// http://doc.spip.org/@autoriser_mot_iconifier_dist
+function autoriser_mot_iconifier_dist($faire,$quoi,$id,$qui,$opts){
+ return (($qui['statut'] == '0minirezo') AND !$qui['restreint']);
+}
+// http://doc.spip.org/@autoriser_article_iconifier_dist
+function autoriser_iconifier_dist($faire,$quoi,$id,$qui,$opts){
+	// On reprend le code de l'ancien iconifier pour definir les autorisations pour les autres
+	// objets SPIP. De ce fait meme de nouveaux objets bases sur cet algorithme peuvent continuer
+	// a fonctionner. Cependant il est recommander de leur definir une autorisation specifique
+	$table = table_objet_sql($quoi);
+	$id_objet = id_table_objet($quoi);
+	$row = sql_fetsel("id_rubrique, statut", $table, "$id_objet=$id");
+	$droit = autoriser('publierdans','rubrique',$row['id_rubrique']);
+
+	if (!$droit AND  ($row['statut'] == 'prepa' OR $row['statut'] == 'prop' OR $row['statut'] == 'poubelle')) {
+	  $jointure = table_jointure('auteur', 'article');
+	  if ($droit = sql_fetsel("id_auteur", "spip_$jointure", "id_article=".sql_quote($id) . " AND id_auteur=$connect_id_auteur"))
+		$droit = true;
+	}
+
+	return $droit;
+}
+
 // Deux fonctions sans surprise pour permettre les tests
 // Dire toujours OK
 // http://doc.spip.org/@autoriser_ok_dist
