@@ -3,7 +3,7 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2010                                                *
+ *  Copyright (c) 2001-2011                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
@@ -19,7 +19,7 @@
  *
  */
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 include_spip('inc/plugin');
 include_spip('inc/actions');
@@ -219,13 +219,17 @@ function chargeur_charger_zip($quoi = array())
 	$list = $zip->listContent();
 
 	// on cherche la plus longue racine commune a tous les fichiers
+	$max_n = 999999;
 	foreach($list as $n) {
 		$p = array();
 		foreach(explode('/', $n['filename']) as $n => $x) {
+			if ($n>$max_n)
+				continue;
 			$sofar = join('/',$p);
 			$paths[$n][$sofar]++;
 			$p[] = $x;
 		}
+		$max_n = min($n,$max_n);
 	}
 
 	$total = $paths[0][''];
