@@ -3,14 +3,14 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2010                                                *
+ *  Copyright (c) 2001-2011                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 include_spip('inc/actions'); // *action_auteur et determine_upload
 include_spip('inc/date');
@@ -46,7 +46,7 @@ function get_spip_doc($fichier) {
 
 // Constante indiquant le charset probable des documents non utf-8 joints
 
-@define('CHARSET_JOINT', 'iso-8859-1');
+if (!defined('CHARSET_JOINT')) define('CHARSET_JOINT', 'iso-8859-1');
 
 // Filtre pour #FICHIER permettant d'incruster le contenu d'un document
 // Si 2e arg fourni, conversion dans le charset du site si possible
@@ -96,9 +96,8 @@ function generer_url_document_dist($id_document, $args='', $ancre='') {
 
 	// Si droit de voir tous les docs, pas seulement celui-ci
 	// il est inutilement couteux de rajouter une protection
-	// idem si ce doc est visible par tous
-	$r = (autoriser('voir', 'document')
-		OR autoriser('voir', 'document', $id_document, array()));
+
+	$r = autoriser('voir', 'document');
 
 	if ($r AND $r !== 'htaccess') return get_spip_doc($f);
 
@@ -152,7 +151,7 @@ function document_et_vignette($document, $url, $portfolio=false) {
 function vignette_automatique($img, $doc, $lien, $x=0, $y=0, $align='', $class='spip_logos')
 {
 	include_spip('inc/distant');
-	include_spip('inc/filtres');
+	include_spip('inc/texte');
 	include_spip('inc/filtres_images_mini');
 	$e = $doc['extension'];
 	if (!$img) {
