@@ -3,14 +3,14 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2010                                                *
+ *  Copyright (c) 2001-2011                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 include_spip('inc/charsets');
 include_spip('inc/filtres_mini');
@@ -318,7 +318,9 @@ function proteger_amp($texte){
 }
 // http://doc.spip.org/@entites_html
 function entites_html($texte, $tout=false) {
-	if (!is_string($texte) OR !$texte) return $texte;
+	if (!is_string($texte) OR !$texte
+	OR !preg_match(",[&\"'<>],S", $texte) # strpbrk($texte, "&\"'<>")!==false
+	) return $texte;
 	include_spip('inc/texte');
 	$texte = htmlspecialchars(echappe_retour(echappe_html($texte,'',true),'','proteger_amp'));
 	if ($tout)
@@ -340,15 +342,19 @@ function filtrer_entites($texte) {
 // caracteres de controle - http://www.w3.org/TR/REC-xml/#charsets
 // http://doc.spip.org/@supprimer_caracteres_illegaux
 function supprimer_caracteres_illegaux($texte) {
-	$from = "\x0\x1\x2\x3\x4\x5\x6\x7\x8\xB\xC\xE\xF\x10\x11\x12\x13\x14\x15\x16\x17\x18\x19\x1A\x1B\x1C\x1D\x1E\x1F";
-	$to = str_repeat('-', strlen($from));
+	static $from = "\x0\x1\x2\x3\x4\x5\x6\x7\x8\xB\xC\xE\xF\x10\x11\x12\x13\x14\x15\x16\x17\x18\x19\x1A\x1B\x1C\x1D\x1E\x1F";
+	static $to = null;
+	
+	if (is_array($texte)) {
+		return array_map('supprimer_caracteres_illegaux', $texte);
+	}
+	if (!$to) $to = str_repeat('-', strlen($from));
 	return strtr($texte, $from, $to);
 }
 
 // Supprimer caracteres windows et les caracteres de controle ILLEGAUX
 // http://doc.spip.org/@corriger_caracteres
 function corriger_caracteres ($texte) {
-	include_spip('inc/charsets');
 	$texte = corriger_caracteres_windows($texte);
 	$texte = supprimer_caracteres_illegaux($texte);
 	return $texte;
@@ -467,8 +473,9 @@ function PtoBR($texte){
 }
 
 // Couper les "mots" de plus de $l caracteres (souvent des URLs)
+// en mettant des espaces (par defaut, soft hyphen &#173: = &shy;)
 // http://doc.spip.org/@lignes_longues
-function lignes_longues($texte, $l = 70) {
+function lignes_longues($texte, $l = 70, $espace='&#173;') {
 	if ($l<1) return $texte;
 	if (!preg_match("/[\w,\/.]{".$l."}/UmsS", $texte))
 		return $texte;
@@ -493,7 +500,7 @@ function lignes_longues($texte, $l = 70) {
 	// note : on pourrait preferer couper sur les / , etc.
 	if (preg_match_all("/[\w,\/.]{".$l."}/UmsS", $texte, $longs, PREG_SET_ORDER)) {
 		foreach ($longs as $long) {
-			$texte = str_replace($long[0], $long[0].' ', $texte);
+			$texte = str_replace($long[0], $long[0].$espace, $texte);
 		}
 	}
 
@@ -1135,7 +1142,7 @@ function date_fin_semaine($annee, $mois, $jour) {
 // http://doc.spip.org/@agenda_connu
 function agenda_connu($type)
 {
-  return in_array($type, array('jour','mois','semaine','periode')) ? ' ' : '';
+  return in_array($type, array('jour','mois','semaine','periode', 'trimestre')) ? ' ' : '';
 }
 
 
@@ -1177,16 +1184,12 @@ function agenda_memo($date=0 , $descriptif='', $titre='', $url='', $cal='')
 // http://doc.spip.org/@agenda_affiche
 function agenda_affiche($i)
 {
-	include_spip('inc/agenda');
 	$args = func_get_args();
-	// date ou nombre d'evenements (on pourrait l'afficher)
+	// date (ou nombre d'evenements qu'on pourrait alors afficher)
 	$nb = array_shift($args);
 	$evt = array_shift($args);
 	$type = array_shift($args);
-		spip_log("evt $nb");
-	if (!$nb) {
-		$d = array(time());
-	} else {
+	if ($nb) {
 		$agenda = agenda_memo(0);
 		$evt = array();
 		foreach (($args ? $args : array_keys($agenda)) as $k) {
@@ -1195,27 +1198,51 @@ function agenda_affiche($i)
 					$evt[$d] = $evt[$d] ? (array_merge($evt[$d], $v)) : $v;
 				}
 		}
-		$d = array_keys($evt);
-	}
-	if (count($d)){
-		$mindate = min($d);
-		$start = strtotime($mindate);
-	} else {
-		$mindate = ($j=_request('jour')) * ($m=_request('mois')) * ($a=_request('annee'));
-  		if ($mindate)
-			$start = mktime(0,0,0, $m, $j, $a);
-  		else $start = mktime(0,0,0);
 	}
+	return agenda_periode($type, $nb, $evt);
+}
+
+function agenda_periode($type, $nb, $avec, $sans='')
+{
+	include_spip('inc/agenda');
+	$start = agenda_controle();
+	if ($start<0) $start = time();
+	$mindate = date("Ymd", $start);
+
 	if ($type != 'periode')
-		$evt = array('', $evt);
+		$evt = array($sans, $avec);
 	else {
 		$min = substr($mindate,6,2);
-		$max = $min + ((strtotime(max($d)) - $start) / (3600 * 24));
+		$max = !(is_array($avec) AND $avec) ? time() : strtotime(max(array_keys($avec)));
+		$max = $min + (($max - $start) / (3600 * 24));
 		if ($max < 31) $max = 0;
-		$evt = array('', $evt, $min, $max);
+		$evt = array($sans, $avec, $min, $max);
 		$type = 'mois';
 	}
-	return http_calendrier_init($start, $type,  _request('echelle'), _request('partie_cal'), self('&'), $evt);
+	$ancre = _request('ancre');
+	$s =  self('&') . (preg_match('/^[\w-]+$/', $ancre) ? "#$ancre" : '');
+	return http_calendrier_init($start, $type,  _request('echelle'), _request('partie_cal'), $s, $evt);
+}
+
+
+// Controle la coherence des 3 nombres d'une date et retourne le temps Unix,
+// sinon retourne un code d'erreur, toujours negatif
+function agenda_controle($date='date', $jour='jour', $mois='mois', $annee='annee')
+{
+	$jour = _request($jour);
+	$mois = _request($mois);
+	$annee = _request($annee);
+
+	if (!($jour||$mois||$anne)) {
+		if ($date = recup_date(_request($date))) {
+			list($annee, $mois, $jour ) = $date;
+		} else  return -1;
+	}
+	if (!$d = mktime(0,0,0, $mois, $jour, $annee)) return -2;
+	if ($jour != date("d", $d)) return -3;
+	if ($mois != date("m", $d)) return -4;
+	if ($annee != date("Y", $d)) return -5;
+	return $d;
 }
 
 //
@@ -1292,11 +1319,10 @@ function extraire_multi($letexte, $lang=null, $echappe_span=false) {
 				$l = key($trads);
 				$trad = $trads[$l];
 				$typographie = charger_fonction(lang_typo($l), 'typographie');
-				$trad = $typographie($trad);
+				$trad = traiter_retours_chariots($typographie($trad));
 				$trad = explode("\n", $trad);
 				foreach($trad as $i => $ligne) {
 					if (strlen($ligne)) {
-						$e = true;
 						$ligne = code_echappement($ligne, 'multi');
 						$ligne = str_replace("'", '"', inserer_attribut($ligne, 'lang', $l));
 						if (lang_dir($l) !== lang_dir($lang))
@@ -1577,6 +1603,10 @@ function modulo($nb, $mod, $add=0) {
 //  retourne false ou la  normalisation de la derniere adresse donnee
 // http://doc.spip.org/@email_valide
 function email_valide($adresses) {
+	// eviter d'injecter n'importe quoi dans preg_match
+	if (!is_string($adresses))
+		return false;
+
 	// Si c'est un spammeur autant arreter tout de suite
 	if (preg_match(",[\n\r].*(MIME|multipart|Content-),i", $adresses)) {
 		spip_log("Tentative d'injection de mail : $adresses");
@@ -1787,7 +1817,7 @@ function form_hidden($action) {
 			.'"'
 			. (is_null($val)
 				? ''
-				: ' value="'.entites_html($val).'"'
+				: ' value="'.str_replace("'","&#39;",entites_html($val)).'"'
 				)
 			. ' type="hidden" />';
 	}
@@ -1858,6 +1888,7 @@ function filtre_pagination_dist($total, $nom, $position, $pas, $liste = true, $m
 	if (!$liste)
 		return $ancres[$ancre];
 
+	$position = min($position,$total);
 	$pagination = array(
 		'debut' => $debut,
 		'url' => parametre_url(self(),'fragment',''), // nettoyer l'id ahah eventuel
@@ -1891,12 +1922,17 @@ function urls_absolues_css($contenu, $source) {
 		create_function('$x',
 			'return "url(\"".suivre_lien("'.$path.'",$x[1])."\")";'
 		), $contenu);
-	// pour les progid:DXImageTransform.Microsoft.AlphaImageLoader(src=...,..)
+
+  // les directives filter ... progid:DXImageTransform.Microsoft.AlphaImageLoader(src=...,..)
+	// de IEx prennent des urls relatives a la page, et non a la css
+	// ne pas y toucher.
+	/*
 	$contenu = preg_replace_callback(
 		";\(\s*src=['\"]?([^'\"/][^:]*)['\"]?\s*(,|\));Uims",
 		create_function('$x',
 			'return "(src=\"".suivre_lien("'.$path.'",$x[1])."\"".$x[2];'
 		), $contenu);
+	 */
 	return $contenu;
 }
 
@@ -2150,7 +2186,8 @@ function f_jQuery ($texte) {
 		array(
 			'javascript/jquery.js',
 			'javascript/jquery.form.js',
-			'javascript/ajaxCallback.js'
+			'javascript/ajaxCallback.js',
+			'javascript/jquery.cookie.js'
 		))) as $script)
 			if ($script = find_in_path($script))
 				$x .= "\n<script src=\"$script\" type=\"text/javascript\"></script>\n";
@@ -2274,7 +2311,13 @@ function filtre_info_plugin_dist($plugin, $type_info) {
 		return $plugins_actifs[$plugin][$type_info];
 	else {
 		$get_infos = charger_fonction('get_infos','plugins');
-		$infos = $get_infos($plugins_actifs[$plugin]['dir']);
+		// On prend en compte les extensions
+		if (!is_dir($plugins_actifs[$plugin]['dir_type']))
+			$dir_plugins = constant($plugins_actifs[$plugin]['dir_type']);
+		else
+			$dir_plugins = $plugins_actifs[$plugin]['dir_type'];
+		if (!$infos = $get_infos($plugins_actifs[$plugin]['dir'], false, $dir_plugins))
+			return '';
 		if ($type_info == 'tout')
 			return $infos;
 		else
@@ -2424,22 +2467,30 @@ function _xor($message, $key=null){
  *
  * @param string $url
  * @param string $libelle
+ *   le texte du lien
  * @param bool $on
+ *   etat expose (genere un strong) ou non (genere un lien)
  * @param string $class
  * @param string $title
+ * @param string $rel
+ * @param string $evt
+ *   complement a la balise a pour gerer un evenement javascript, de la forme " onclick='...'"
  * @return string
  */
-function lien_ou_expose($url,$libelle,$on=false,$class="",$title="",$rel=""){
-	return
-	($on ?"<strong class='on'>":
-		"<a href='$url'"
+function lien_ou_expose($url,$libelle,$on=false,$class="",$title="",$rel="", $evt=''){
+	if ($on) {
+		$bal = "strong";
+		$att = "class='on'";
+	} else {
+		$bal = 'a';
+		$att = "href='$url'"
 	  	.($title?" title='".attribut_html($title)."'":'')
 	  	.($class?" class='".attribut_html($class)."'":'')
 	  	.($rel?" rel='".attribut_html($rel)."'":'')
-	  	.">"
-	)
-	. $libelle
-	. ($on ? "</strong>":"</a>");
+		.$evt;
+	}
+
+	return "<$bal $att>$libelle</$bal>";
 }
 
 
@@ -2451,7 +2502,7 @@ function lien_ou_expose($url,$libelle,$on=false,$class="",$title="",$rel=""){
  * @param string $class
  * @return string
  */
-function balise_img($img,$alt="",$class=""){
+function filtre_balise_img_dist($img,$alt="",$class=""){
 	$taille = taille_image($img);
 	list($hauteur,$largeur) = $taille;
 	if (!$hauteur OR !$largeur)
