@@ -3,14 +3,14 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2010                                                *
+ *  Copyright (c) 2001-2011                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 //  Pour ecrire les fichiers memorisant les parametres de connexion
 
@@ -43,23 +43,28 @@ function install_connexion($adr, $port, $login, $pass, $base, $type, $pref, $lda
 	. "spip_connect_db("
 	. "'$adr','$port','$login','$pass','$base'"
 	. ",'$type', '$pref','$ldap');\n";
-
 }
 
+// Analyse si un fichier contient le resultat de la fonction install_connexion
+// y compris ce qu'elle produisait dans les versions precedentes
+
 // http://doc.spip.org/@analyse_fichier_connection
 function analyse_fichier_connection($file)
 {
-
 	$s = @join('', file($file));
 	if (preg_match("#mysql_connect\([\"'](.*)[\"'],[\"'](.*)[\"'],[\"'](.*)[\"']\)#", $s, $regs)) {
 		array_shift($regs);
 		return $regs;
-	} else if (preg_match("#spip_connect_db\('([^']*)'\s*,\s*'([^']*)'\s*,\s*'([^']*)'\s*,\s*'([^']*)'\s*,\s*'([^']*)'\s*,\s*'([^']*)#", $s, $regs)) {
-		$regs[2] = $regs[1] . (!$regs[2] ? '' : ":$port_db;");
-		array_shift($regs);
-		array_shift($regs);
-		return $regs;
-	} else spip_log("$file n'est pas un fichier de connexion");
+	} else {
+		$arg = '\s*\'([^\']*)\'\s*,';
+		if (preg_match("#spip_connect_db\($arg$arg$arg$arg\s*'([^']*)'\s*(?:,\s*'([^']*))?#", $s, $regs)) {
+			$regs[2] = $regs[1] . (!$regs[2] ? '' : ":$port_db;");
+			array_shift($regs);
+			array_shift($regs);
+			return $regs;
+		}
+	}
+	spip_log("$file n'est pas un fichier de connexion");
 	return '';
 }
 
@@ -75,6 +80,13 @@ function bases_referencees($exclu='')
 }
 
 
+function install_mode_appel($server_db, $tout=true)
+{
+	return ($server_db != 'mysql') ? ''
+	: (($tout  ? test_rappel_nom_base_mysql($server_db) : '')
+		. test_sql_mode_mysql($server_db)	);
+}
+
 //
 // Verifier que l'hebergement est compatible SPIP ... ou l'inverse :-)
 // (sert a l'etape 1 de l'installation)
