@@ -3,14 +3,14 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2010                                                *
+ *  Copyright (c) 2001-2011                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 include_spip('inc/actions');
 include_spip('inc/texte');
@@ -94,19 +94,20 @@ function editer_choix_webmestre($auteur){
 
 // http://doc.spip.org/@traduire_statut_auteur
 function traduire_statut_auteur($statut){
-	$recom = array("info_administrateurs" => _T('item_administrateur_2'),
-		       "info_redacteurs" =>  _T('intem_redacteur'),
-		       "info_visiteurs" => _T('item_visiteur'),
-		       '5poubelle' => _T('texte_statut_poubelle'), // bouh
-		       );
+	$recom = array(
+				"info_administrateurs" => 'item_administrateur_2',
+				"info_redacteurs" =>  'intem_redacteur',
+				"info_visiteurs" => 'item_visiteur',
+				"5poubelle" => 'texte_statut_poubelle', // bouh
+			);
 	if (isset($recom[$statut]))
-		return $recom[$statut];
+		return _T($recom[$statut]);
 	
 	// retrouver directement par le statut sinon
 	if ($t = array_search($statut, $GLOBALS['liste_des_statuts'])){
 	  if (isset($recom[$t]))
-			return $recom[$t];
-		return $t;
+			return _T($recom[$t]);
+		return _T($t);
 	}
 	
 	return '';
@@ -135,7 +136,7 @@ function choix_statut_auteur($statut, $id_auteur, $ancre) {
 
 	$menu = '';
 	foreach($droits as $k => $v) {
-		if ($k = traduire_statut_auteur($k))
+		if (($v != '5poubelle') && ($k = traduire_statut_auteur($v)))
 			$menu .=  mySel($v, $statut, $k);
 	}
 
