@@ -3,7 +3,7 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2010                                                *
+ *  Copyright (c) 2001-2011                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
@@ -19,7 +19,7 @@
  http://www.loc.gov/standards/iso639-2/langcodes.html
 */
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 $GLOBALS['codes_langues'] = array(
 	'aa' => "Afar",
@@ -60,6 +60,7 @@ $GLOBALS['codes_langues'] = array(
 	'en_sm' => "Smurf",
 	'eo' => "Esperanto",
 	'es' => "Espa&#241;ol",
+	'es_mx_pop' => "Mexicano a lo g&#252;ey",
 	'es_co' => "Colombiano",
 	'et' => "eesti",
 	'eu' => "euskara",
@@ -83,6 +84,7 @@ $GLOBALS['codes_langues'] = array(
 	'grc' => "&#7944;&#961;&#967;&#945;&#943;&#945; &#7961;&#955;&#955;&#951;&#957;&#953;&#954;&#942;", // grec ancien
 	'gu' => "Gujarati",
 	'ha' => "Hausa",
+	'hac' => "&#1705;-&#1607;&#1734;&#1585;&#1575;&#1605;&#1740;", //"Kurdish-Horami"
 	'hbo' => "&#1506;&#1489;&#1512;&#1497;&#1514;&#1470;&#1492;&#1514;&#1504;&#1498;", // hebreu classique ou biblique
 	'he' => "&#1506;&#1489;&#1512;&#1497;&#1514;",
 	'hi' => "&#2361;&#2367;&#2306;&#2342;&#2368;",
@@ -148,6 +150,7 @@ $GLOBALS['codes_langues'] = array(
 	'om' => "(Afan) Oromo",
 	'or' => "Oriya",
 	'pa' => "Punjabi",
+	'pbb' => 'Nasa Yuwe',
 	'pl' => "polski",
 	'ps' => "Pashto, Pushto",
 	'pt' => "Portugu&#234;s",
