@@ -3,14 +3,14 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2010                                                *
+ *  Copyright (c) 2001-2011                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 include_spip('base/abstract_sql');
 
@@ -23,6 +23,22 @@ include_spip('base/abstract_sql');
 // http://doc.spip.org/@traiter_raccourci_lien_lang
 function inc_lien_dist($lien, $texte='', $class='', $title='', $hlang='', $rel='', $connect='')
 {
+	// Si une langue est demandee sur un raccourci d'article, chercher
+	// la traduction ;
+	// - [{en}->art2] => traduction anglaise de l'article 2, sinon art 2
+	// - [{}->art2] => traduction en langue courante de l'art 2, sinon art 2
+	if ($hlang
+	AND $match = typer_raccourci($lien)) { 
+		@list($type,,$id,,$args,,$ancre) = $match; 
+		if ($id_trad = sql_getfetsel('id_trad', 'spip_articles', "id_article=$id")
+		AND $id_dest = sql_getfetsel('id_article', 'spip_articles',
+			"id_trad=$id_trad  AND statut<>'refuse' AND lang=" . sql_quote($hlang))
+		)
+			$lien = "$type$id_dest";
+		else
+			$hlang = '';
+	}
+
 	$mode = ($texte AND $class) ? 'url' : 'tout';
 	$lien = calculer_url($lien, $texte, $mode, $connect);
 	if ($mode === 'tout') {
@@ -36,7 +52,7 @@ function inc_lien_dist($lien, $texte='', $class='', $title='', $hlang='', $rel='
 		$class = 'spip_ancre';
 	elseif (preg_match('/^\s*mailto:/',$lien)) # pseudo URL de mail
 		$class = "spip_mail";
-	elseif (preg_match('/^<html>/',$lien)) # cf traiter_lien_explicite
+	elseif (preg_match('/^<html>/',$texte)) # cf traiter_lien_explicite
 		$class = "spip_url spip_out";
 	elseif (!$class) $class = "spip_out"; # si pas spip_in|spip_glossaire
 
@@ -54,7 +70,7 @@ function inc_lien_dist($lien, $texte='', $class='', $title='', $hlang='', $rel='
 		$rel = trim("$rel external");
 	if ($rel) $rel = " rel='$rel'";
 
-	$lien = "<a href='$lien' class='$class'$lang$title$rel$mime>$texte</a>";
+	$lien = "<a href=\"".str_replace('"', '&quot;', $lien)."\" class='$class'$lang$title$rel$mime>$texte</a>";
 
 	# ceci s'execute heureusement avant les tableaux et leur "|".
 	# Attention, le texte initial est deja echappe mais pas forcement
@@ -119,7 +135,11 @@ function nettoyer_raccourcis_typo($texte, $connect='')
 			if (!$titre) {
 				$match = typer_raccourci($reg[count($reg)-1]);
 				@list($type,,$id,,,,) = $match;
-				if ($type) $titre = traiter_raccourci_titre($id, $type, $connect);
+				if ($type) {
+					$url = generer_url_entite($id,$type,'','',true);
+					if (is_array($url)) list($type, $id) = $url;
+					$titre = traiter_raccourci_titre($id, $type, $connect);
+				}
 				$titre = $titre ? $titre['titre'] : $match[0];
 			}
 			$titre = corriger_typo(supprimer_tags($titre));
@@ -217,16 +237,23 @@ function traiter_raccourci_liens($t) {
 	return preg_replace_callback(_EXTRAIRE_LIENS, 'traiter_autoliens', $t);
 }
 
-// Fonction pour les champs chapo commencant par =,  redirection qui peut etre:
-// 1. un raccourci Spip habituel (premier If) [texte->TYPEnnn]
-// 2. un ultra raccourci TYPEnnn voire nnn (article) (deuxieme If)
-// 3. une URL std
-// renvoie une tableau structure comme ci-dessus mais sans calcul d'URL
-// (cf fusion de sauvegardes)
 
 define('_RACCOURCI_CHAPO', '/^(\W*)(\W*)(\w*\d+([?#].*)?)$/');
-
-// http://doc.spip.org/@chapo_redirige
+/**
+ * Fonction pour les champs chapo commencant par =,  redirection qui peut etre:
+ * 1. un raccourci Spip habituel (premier If) [texte->TYPEnnn]
+ * 2. un ultra raccourci TYPEnnn voire nnn (article) (deuxieme If)
+ * 3. une URL std
+ *
+ * renvoie l'url reelle de redirection si le $url=true,
+ * l'url brute contenue dans le chapo sinon
+ *
+ * http://doc.spip.org/@chapo_redirige
+ *
+ * @param string $chapo
+ * @param bool $url
+ * @return string
+ */
 function chapo_redirige($chapo, $url=false)
 {
 	if (!preg_match(_RACCOURCI_LIEN, $chapo, $m))
@@ -274,12 +301,8 @@ function traiter_lien_explicite ($ref, $texte='', $pour='url', $connect='')
 	if (!$texte) {
 		$texte = str_replace('"', '', $lien);
 		// evite l'affichage de trops longues urls.
-		// personnalisation possible dans mes_options
-		$long_url = defined('_MAX_LONG_URL') ? _MAX_LONG_URL : 40;
-		$coupe_url = defined('_MAX_COUPE_URL') ? _MAX_COUPE_URL : 35;
-		if (strlen($texte)>$long_url) {
-			$texte = substr($texte,0,$coupe_url).'...';
-		}
+		$lien_court = charger_fonction('lien_court', 'inc');
+		$texte = $lien_court($texte);
 		$texte = "<html>".quote_amp($texte)."</html>";
 	}
 
@@ -354,7 +377,6 @@ function typer_raccourci ($lien) {
 		$f = 'document';
 	else if (preg_match('/^br..?ve$/S', $f)) $f = 'breve'; # accents :(
 	$match[0] = $f;
-	$match[2] = entites_html($match[2]);
 	return $match;
 }
 
@@ -389,7 +411,7 @@ define('_RACCOURCI_MODELE',
 	.'\s*(<\/a>)?' # eventuel </a>
        );
 
-define('_RACCOURCI_MODELE_DEBUT', '@^' . _RACCOURCI_MODELE .'@is');
+define('_RACCOURCI_MODELE_DEBUT', '@^' . _RACCOURCI_MODELE .'@isS');
 
 // http://doc.spip.org/@traiter_modeles
 function traiter_modeles($texte, $doublons=false, $echap='', $connect='', $liens = null) {
@@ -397,8 +419,8 @@ function traiter_modeles($texte, $doublons=false, $echap='', $connect='', $liens
 	if ($doublons===true)
 		$doublons = array('documents'=>array('doc','emb','img'));
 	// detecter les modeles (rapide)
-	if (preg_match_all('/<[a-z_-]{3,}\s*[0-9|]+/iS',
-	$texte, $matches, PREG_SET_ORDER)) {
+	if (strpos($texte,"<")!==false AND
+	  preg_match_all('/<[a-z_-]{3,}\s*[0-9|]+/iS', $texte, $matches, PREG_SET_ORDER)) {
 		include_spip('public/assembler');
 		foreach ($matches as $match) {
 			// Recuperer l'appel complet (y compris un eventuel lien)
