@@ -3,14 +3,14 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2010                                                *
+ *  Copyright (c) 2001-2011                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 // http://doc.spip.org/@inc_meme_rubrique_dist
 function inc_meme_rubrique_dist($id_rubrique, $id, $type, $order='', $limit=NULL, $ajax=false)
 {
@@ -26,7 +26,7 @@ function inc_meme_rubrique_dist($id_rubrique, $id, $type, $order='', $limit=NULL
 	}
 	$prim = 'id_' . $type;
 	if (!$limit)
-		$limit = defined("_MAX_ART_AFFICHES") ? _MAX_ART_AFFICHES : 10;
+		$limit = defined('_MAX_ART_AFFICHES') ? _MAX_ART_AFFICHES : 10;
 
 	$titre = ($type!='syndic'?'titre':'nom_site');
 	$exec = array('article'=>'articles','breve'=>'breves_voir','syndic'=>'sites');
