@@ -3,14 +3,14 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2010                                                *
+ *  Copyright (c) 2001-2011                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 
 // Une fonction generique pour l'API de modification de contenu
@@ -113,6 +113,26 @@ function modifier_contenu($type, $id, $options, $c=false, $serveur='') {
 		// allez on commit la modif
 		sql_updateq($spip_table_objet, $champs, "$id_table_objet=$id", $serveur);
 
+		// on verifie si elle est bien passee
+		// pour detecter le cas ou un caractere illicite a ete utilise dans un champ texte
+		// et provoque la troncature du champ lors de l'enregistrement
+		$moof = sql_fetsel(array_keys($champs), $spip_table_objet, "$id_table_objet=$id", array(), array(), '', array(), $serveur);
+		if ($moof != $champs) {
+			foreach($moof as $k=>$v) {
+				if ($v !== $champs[$k]
+					// ne pas alerter si le champ est d'un type numerique ou date
+				  // car c'est surement un cast sql, tout a fait normal
+				  // sinon cela provoque des fausses alertes a la moindre saisie vide
+				  // ou n'ayant pas la bonne resolution numerique ou le bon format
+					AND (!preg_match(',(int|float|double|date|time|year|enum|decimal),',$desc['field'][$k]))
+					) {
+					$conflits[$k]['post'] = $champs[$k];
+					$conflits[$k]['save'] = $v;
+				}
+			}
+		}
+
+
 		// Cas particulier des groupes de mots dont le titre est repris
 		// dans la table spip_mots
 		if ($spip_table_objet == 'spip_groupes_mots'
@@ -126,9 +146,11 @@ function modifier_contenu($type, $id, $options, $c=false, $serveur='') {
 			suivre_invalideur($options['invalideur']);
 		}
 
-		// marquer les documents vus dans le texte si il y a lieu
-		include_spip('base/auxiliaires');
-		marquer_doublons_documents($champs,$id,$type,$id_table_objet,$table_objet,$spip_table_objet, $desc, $serveur);
+		if (!in_array($type,array('forum','signature'))) {
+			// marquer les documents vus dans le texte si il y a lieu
+			include_spip('base/auxiliaires');
+			marquer_doublons_documents($champs,$id,$type,$id_table_objet,$table_objet,$spip_table_objet, $desc, $serveur);
+		}
 
 		// Notifications, gestion des revisions...
 		// appelle |enregistrer_nouvelle_revision @inc/revisions
@@ -148,9 +170,9 @@ function modifier_contenu($type, $id, $options, $c=false, $serveur='') {
 			)
 		);
 	}
-
+	
 	// S'il y a un conflit, prevenir l'auteur de faire un copier/coller
-	if ($conflit AND count($conflits)) {
+	if ($conflits) {
 		$redirect = url_absolue(
 			parametre_url(rawurldecode(_request('redirect')), $id_table_objet, $id)
 		);
