@@ -3,14 +3,14 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2010                                                *
+ *  Copyright (c) 2001-2011                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 include_spip('inc/agenda'); // inclut inc/layer, inc/texte, inc/filtre
 include_spip('inc/boutons');
@@ -927,9 +927,9 @@ function fin_page()
 			.  _T("access_interface_graphique")
 			. "</a></div>")
 		: ("<div style='text-align: right; ' class='verdana1 spip_xx-small'>"
-			. info_maj_spip()
 			. info_copyright()
 			. "<br />"
+			. info_maj_spip()
 			. _T('info_copyright_doc',
 				array('spipnet' => $GLOBALS['home_server']
 					. '/' .    $GLOBALS['spip_lang']))
@@ -953,16 +953,20 @@ function info_maj_spip(){
 
 	$maj = explode('|',$maj);
 	// c'est une ancienne notif, on a fait la maj depuis !
-	if ($GLOBALS['spip_version_branche']!==reset($maj))
+	if ($GLOBALS['spip_version_branche']!==array_shift($maj))
 		return "";
 
 	if (!autoriser('webmestre'))
 		return "";
 
-	array_shift($maj);
 	$maj = implode('|',$maj);
+	if (strncmp($maj,"<a",2)==0) $maj = extraire_attribut ($maj, 'title');
+	$lien = "http://www.spip.net/".$GLOBALS['spip_lang']."_download";
+	$maj = "<a class='info_maj_spip' href='$lien'><strong>" .
+	    _T('nouvelle_version_spip',array('version'=>$maj)) .
+	    '</strong></a>.';
 
-	return "<br />$maj</br>";
+	return "$maj<br />";
 }
 
 // http://doc.spip.org/@info_copyright
@@ -976,7 +980,7 @@ function info_copyright() {
 	//
 	if ($svn_revision = version_svn_courante(_DIR_RACINE)) {
 		$version .= ' ' . (($svn_revision < 0) ? 'SVN ':'')
-		. "[<a href='http://trac.rezo.net/trac/spip/changeset/"
+		. "[<a href='http://core.spip.org/trac/spip/changeset/"
 		. abs($svn_revision) . "' onclick=\"window.open(this.href); return false;\">"
 		. abs($svn_revision) . "</a>]";
 	}
