@@ -3,14 +3,14 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2010                                                *
+ *  Copyright (c) 2001-2011                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 // interface d'appel:
 // - au moins un argument: retourne une URL ou un formulaire securises
@@ -48,7 +48,7 @@ function securiser_action_auteur($action, $arg, $redirect="", $mode=false, $att=
 		if ($mode===-1)
 			return array('action'=>$action,'arg'=>$arg,'hash'=>$hash);
 		else
-			return generer_url_action($action, "arg=$arg&hash=$hash" . (!$r ? '' : "&redirect=$r"), $mode, $att);
+			return generer_url_action($action, "arg=$arg&hash=$hash" . (!$r ? '' : "&redirect=$r"), $mode, $public);
 	}
 
 	$att .= " style='margin: 0px; border: 0px'";
@@ -113,7 +113,7 @@ function _action_auteur($action, $id_auteur, $pass, $alea) {
 			}
 		}
 		include_spip('auth/sha256.inc');
-		$sha[$id_auteur.$pass.$alea] = sha256($id_auteur.$pass.@$GLOBALS['meta'][$alea]);
+		$sha[$id_auteur.$pass.$alea] = _nano_sha256($id_auteur.$pass.@$GLOBALS['meta'][$alea]);
 	}
 	if (function_exists('sha1'))
 		return sha1($action.$sha[$id_auteur.$pass.$alea]);
@@ -154,7 +154,7 @@ function secret_du_site() {
 	  OR (strlen($GLOBALS['meta']['secret_du_site'])<64)) {
 		include_spip('inc/acces');
 		include_spip('auth/sha256.inc');
-		ecrire_meta('secret_du_site', sha256($_SERVER["DOCUMENT_ROOT"] . $_SERVER["SERVER_SIGNATURE"] . creer_uniqid()), 'non');
+		ecrire_meta('secret_du_site', _nano_sha256($_SERVER["DOCUMENT_ROOT"] . $_SERVER["SERVER_SIGNATURE"] . creer_uniqid()), 'non');
 		lire_metas(); // au cas ou ecrire_meta() ne fonctionne pas
 	}
 	return $GLOBALS['meta']['secret_du_site'];
