@@ -3,7 +3,7 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2010                                                *
+ *  Copyright (c) 2001-2011                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
@@ -12,13 +12,13 @@
 
 
 //
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 // Ces commentaires vont etre substitue's en mode recherche
 // voir les champs SURLIGNE dans inc-index-squel
 
-define("MARQUEUR_SURLIGNE",  'debut_surligneconditionnel');
-define("MARQUEUR_FSURLIGNE", 'finde_surligneconditionnel');
+define('MARQUEUR_SURLIGNE',  'debut_surligneconditionnel');
+define('MARQUEUR_FSURLIGNE', 'finde_surligneconditionnel');
 
 
 // http://doc.spip.org/@surligner_mots
