@@ -3,14 +3,14 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2010                                                *
+ *  Copyright (c) 2001-2011                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 include_spip('inc/filtres');
 include_spip('inc/lang');
@@ -102,7 +102,7 @@ function definir_puce() {
 
 // XHTML - Preserver les balises-bloc : on liste ici tous les elements
 // dont on souhaite qu'ils provoquent un saut de paragraphe
-define('_BALISES_BLOCS',
+if (!defined('_BALISES_BLOCS')) define('_BALISES_BLOCS',
 	'div|pre|ul|ol|li|blockquote|h[1-6r]|'
 	.'t(able|[rdh]|body|foot|extarea)|'
 	.'form|object|center|marquee|address|'
@@ -209,25 +209,25 @@ $preg='') {
 	if (!is_string($letexte) or !strlen($letexte))
 		return $letexte;
 
-	if (preg_match_all($preg ? $preg : _PROTEGE_BLOCS,
-	$letexte, $matches, PREG_SET_ORDER))
-	foreach ($matches as $regs) {
-		// echappements tels quels ?
-		if ($no_transform) {
-			$echap = $regs[0];
+	if (($preg OR strpos($letexte,"<")!==false) 
+	  AND preg_match_all($preg ? $preg : _PROTEGE_BLOCS, $letexte, $matches, PREG_SET_ORDER))
+		foreach ($matches as $regs) {
+			// echappements tels quels ?
+			if ($no_transform) {
+				$echap = $regs[0];
+			}
+
+			// sinon les traiter selon le cas
+			else if (function_exists($f = 'traiter_echap_'.strtolower($regs[1])))
+				$echap = $f($regs);
+			else if (function_exists($f = $f.'_dist'))
+				$echap = $f($regs);
+
+			$letexte = str_replace($regs[0],
+				code_echappement($echap, $source, $no_transform),
+				$letexte);
 		}
 
-		// sinon les traiter selon le cas
-		else if (function_exists($f = 'traiter_echap_'.strtolower($regs[1])))
-			$echap = $f($regs);
-		else if (function_exists($f = $f.'_dist'))
-			$echap = $f($regs);
-
-		$letexte = str_replace($regs[0],
-			code_echappement($echap, $source, $no_transform),
-			$letexte);
-	}
-
 	if ($no_transform)
 		return $letexte;
 
@@ -238,7 +238,7 @@ $preg='') {
 	}
 
 	// Echapper le php pour faire joli (ici, c'est pas pour la securite)
-	if (preg_match_all(',<[?].*($|[?]>),UisS',
+	if (strpos($letexte,"<"."?")!==false AND preg_match_all(',<[?].*($|[?]>),UisS',
 	$letexte, $matches, PREG_SET_ORDER))
 	foreach ($matches as $regs) {
 		$letexte = str_replace($regs[0],
@@ -257,7 +257,8 @@ $preg='') {
 function echappe_retour($letexte, $source='', $filtre = "") {
 	if (strpos($letexte,"base64$source")) {
 		# spip_log(htmlspecialchars($letexte));  ## pour les curieux
-		if (preg_match_all(',<(span|div) class=[\'"]base64'.$source.'[\'"]\s(.*)>\s*</\1>,UmsS',
+		if (strpos($letexte,"<")!==false AND
+		  preg_match_all(',<(span|div) class=[\'"]base64'.$source.'[\'"]\s(.*)>\s*</\1>,UmsS',
 		$letexte, $regs, PREG_SET_ORDER)) {
 			foreach ($regs as $reg) {
 				$rempl = base64_decode(extraire_attribut($reg[0], 'title'));
@@ -375,7 +376,7 @@ function couper($texte, $taille=50, $suite = '&nbsp;(...)') {
 
 // afficher joliment les <script>
 // http://doc.spip.org/@echappe_js
-function echappe_js($t,$class='') {
+function echappe_js($t,$class=' class="echappe-js"') {
 	if (preg_match_all(',<script.*?($|</script.),isS', $t, $r, PREG_SET_ORDER))
 	foreach ($r as $regs)
 		$t = str_replace($regs[0],
@@ -434,7 +435,7 @@ function interdire_scripts($arg) {
 	switch($GLOBALS['filtrer_javascript']) {
 		case 0:
 			if (!_DIR_RESTREINT)
-				$t = echappe_js($t,' style="color:red"');
+				$t = echappe_js($t);
 			break;
 		case -1:
 			$t = echappe_js($t);
@@ -502,7 +503,6 @@ function typo($letexte, $echapper=true, $connect=null) {
 	//
 	// NOTE : propre() ne passe pas par ici mais directement par corriger_typo
 	// cf. inc/lien
-
 	$letexte = traiter_modeles($mem = $letexte, false, $echapper ? 'TYPO' : '', $connect);
 	if ($letexte != $mem) $echapper = true;
 	unset($mem);
@@ -529,7 +529,6 @@ define('_TYPO_BALISE', ",</?[a-z!][^<>]*[".preg_quote(_TYPO_PROTEGER)."][^<>]*>,
 
 // http://doc.spip.org/@corriger_typo
 function corriger_typo($letexte, $lang='') {
-
 	// Plus vite !
 	if (!$letexte) return $letexte;
 
@@ -577,7 +576,7 @@ function corriger_typo($letexte, $lang='') {
 // Tableaux
 //
 
-define('_RACCOURCI_TH_SPAN', '\s*(:?{{[^{}]+}}\s*)?|<');
+define('_RACCOURCI_TH_SPAN', '\s*(?:{{[^{}]+}}\s*)?|<');
 
 // http://doc.spip.org/@traiter_tableau
 function traiter_tableau($bloc) {
@@ -607,7 +606,7 @@ function traiter_tableau($bloc) {
 			}
 		// - <thead> sous la forme |{{titre}}|{{titre}}|
 		//   Attention thead oblige a avoir tbody
-			else if (preg_match($reg_line1,	$ligne, $thead)) {
+			else if (preg_match($reg_line1,	$ligne)) {
 			  	preg_match_all('/\|([^|]*)/S', $ligne, $cols);
 				$ligne='';$cols= $cols[1];
 				$colspan=1;
@@ -654,6 +653,9 @@ function traiter_tableau($bloc) {
 	$rowspans = $numeric = array();
 	$n = count($lignes[0]);
 	$k = count($lignes);
+	// distinguer les colonnes numeriques a point ou a virgule,
+	// pour les alignements eventuels sur "," ou "."
+	$numeric_class = array('.'=>'point',','=>'virgule');
 	for($i=0;$i<$n;$i++) {
 	  $align = true;
 	  for ($j=0;$j<$k;$j++) $rowspans[$j][$i] = 1;
@@ -665,13 +667,7 @@ function traiter_tableau($bloc) {
 		else if ($r[1]) $align = $r[1];
 	      }
 	  }
-	  $numeric[$i] = !$align ? '' :
-	    (" style='text-align: " .
-	     // http://www.w3.org/TR/REC-CSS2/tables.html#column-alignment
-	     // specifie text-align: "," pour cadrer le long de la virgule
-	     // mais les navigateurs ne l'implementent pas ou mal
-	     (/* $align !== true ?"\"$align\"" : */ 'right') .
-	     "'");
+	  $numeric[$i] = !$align ? '' : (" class='numeric ".$numeric_class[$align]."'");
 	}
 
 	// et on parcourt le tableau a l'envers pour ramasser les
@@ -729,6 +725,7 @@ function traiter_listes ($texte) {
 	// chaque paragraphe est traite a part
 	while (list(,$para) = each($parags)) {
 		$niveau = 0;
+		$pile_li = $pile_type = array();
 		$lignes = explode("\n-", "\n" . $para);
 
 		// ne pas toucher a la premiere ligne
@@ -768,6 +765,10 @@ function traiter_listes ($texte) {
 				// puis les montees (y compris apres une descente un cran trop bas)
 				while ($niveau < $profond) {
 					if ($niveau == 0) $ajout .= "\n\n";
+					elseif (!isset($pile_li[$niveau])) {
+						$ajout .= "<li$class_spip>";
+						$pile_li[$niveau] = "</li>";
+					}
 					$niveau ++;
 					$ajout .= "<$type$class_spip_plus>";
 					$pile_type[$niveau] = "</$type>";
