@@ -3,14 +3,14 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2010                                                *
+ *  Copyright (c) 2001-2011                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 //
 // Utilitaires indispensables autour du serveur Http.
@@ -194,6 +194,16 @@ function set_request($var, $val = NULL, $c=false) {
 	return false; # n'affecte pas $c
 }
 
+
+/**
+ * Tester si une url est absolue
+ * @param  $url
+ * @return bool
+ */
+function tester_url_absolue($url){
+	return preg_match(";^([a-z]+:)?//;Uims",trim($url))?true:false;
+}
+
 //
 // Prend une URL et lui ajoute/retire un parametre.
 // Exemples : [(#SELF|parametre_url{suite,18})] (ajout)
@@ -277,7 +287,7 @@ function ancre_url($url, $ancre) {
 	}
 	$ancre = preg_replace(array('/^[^-_a-zA-Z0-9]+/', '/[^-_a-zA-Z0-9]/'), array('', '-'),
 					translitteration($ancre));
-	return $url .'#'. $ancre;
+	return $url . (strlen($ancre) ? '#'. $ancre : '');
 }
 
 //
@@ -385,7 +395,7 @@ function _T($texte, $args=array(), $class='') {
 // Aussi appelee quand une chaine n'est pas encore dans les fichiers de langue
 // http://doc.spip.org/@_L
 function _L($text, $args=array(), $class=NULL) {
-
+	$f = $text;
 	if (is_array($args)) {
 		foreach ($args as $name => $value) {
 			if ($class)
@@ -395,7 +405,8 @@ function _L($text, $args=array(), $class=NULL) {
 		}
 		// Si des variables n'ont pas ete inserees, le signaler
 		// (chaines de langues pas a jour)
-		if ($args) spip_log("$text:  variables inutilisees " . join(', ', $args));
+		// NOTE: c'est du debug, gere comme tel pour SPIP >= 2.3
+		## if ($args) spip_log("$f:  variables inutilisees " . join(', ', array_keys($args)));
 	}
 
 	if ($GLOBALS['test_i18n'] AND $class===NULL)
@@ -809,6 +820,7 @@ function generer_url_entite($id='', $entite='', $args='', $ancre='', $public=NUL
 	if ($public === NULL) $public = !test_espace_prive();
 
 	if (!$public) {
+		if (!$entite) return '';
 		include_spip('inc/urls');
 		$f = 'generer_url_ecrire_' . $entite;
 	        $res = !function_exists($f) ? '' : $f($id, $args, $ancre, ' ');
@@ -850,7 +862,7 @@ function generer_url_entite($id='', $entite='', $args='', $ancre='', $public=NUL
 		return $url;
 	}
 	// On a ete gentil mais la ....
-	spip_log("generer_url_entite: entite $entite ($f) inconnue $type");
+	spip_log("generer_url_entite: entite $entite ($f) inconnue $type $public");
 	return '';
 }
 
@@ -950,10 +962,13 @@ function url_de_($http,$host,$request,$prof=0){
 }
 
 
-function tester_url_ecrire($nom)
-{
-	if (find_in_path('prive/exec/' . $nom . '.html')) $nom = 'fond';
-	return charger_fonction($nom,'exec',true);
+function tester_url_ecrire($nom){
+	// tester si c'est une page en squelette
+	if (find_in_path('prive/exec/' . $nom . '.' . _EXTENSION_SQUELETTES))
+		return 'fond';
+	// attention, il ne faut pas inclure l'exec ici car sinon on modifie l'environnement
+	// par un simple #URL_ECRIRE dans un squelette (cas d'un define en debut d'exec/nom )
+	return (find_in_path("{$nom}.php",'exec/') OR charger_fonction($nom,'exec',true))?$nom:'';
 }
 
 // Pour une redirection, la liste des arguments doit etre separee par "&"
@@ -1024,7 +1039,7 @@ function generer_url_public($script='', $args="", $no_entities=false, $rel=false
 		$action = quote_amp($action);
 
 	// ne pas generer une url avec /./?page= en cas d'url absolue et de _SPIP_SCRIPT vide
-	return ($rel ? $action : rtrim(url_de_base(),'/') . preg_replace(",^/[.]/,","/","/$action"));
+	return ($rel ? _DIR_RACINE . $action : rtrim(url_de_base(),'/') . preg_replace(",^/[.]/,","/","/$action"));
 }
 
 // http://doc.spip.org/@generer_url_prive
@@ -1042,15 +1057,17 @@ function generer_url_prive($script, $args="", $no_entities=false) {
 function generer_form_ecrire($script, $corps, $atts='', $submit='') {
 	global $spip_lang_right;
 
+	$script1 = array_shift(explode('&', $script));
+
 	return "<form action='"
 	. ($script ? generer_url_ecrire($script) : '')
 	. "' "
 	. ($atts ? $atts : " method='post'")
 	.  "><div>\n"
-	. "<input type='hidden' name='exec' value='$script' />"
+	. "<input type='hidden' name='exec' value='$script1' />"
 	. $corps
 	. (!$submit ? '' :
-	     ("<div style='text-align: $spip_lang_right'><input type='submit' value='$submit' /></div>"))
+	     ("<div style='text-align: $spip_lang_right'><input type='submit' value=\"".entites_html($submit)."\" /></div>"))
 	. "</div></form>\n";
 }
 
@@ -1297,18 +1314,34 @@ function spip_initialisation_core($pi=NULL, $pa=NULL, $ti=NULL, $ta=NULL) {
 	$inc_meta();
 
 	// nombre de repertoires depuis la racine
-	// on compare a l'adresse donnee en meta ; si celle-ci est fausse
-	// le calcul est faux. Meilleure idee ??
+	// on compare a l'adresse de spip.php : $_SERVER["SCRIPT_NAME"]
+	// ou a defaut celle donnee en meta ; (mais si celle-ci est fausse
+	// le calcul est faux)
 	if (!_DIR_RESTREINT)
 		$GLOBALS['profondeur_url'] = 1;
 	else {
 		$uri = isset($_SERVER['REQUEST_URI']) ? explode('?', $_SERVER['REQUEST_URI']) : '';
-		if (!$uri OR  !isset($GLOBALS['meta']['adresse_site']))
+		$uri_ref = $_SERVER["SCRIPT_NAME"];
+		if (!$uri_ref
+			// si on est appele avec un autre ti, on est sans doute en mutu
+			// si jamais c'est de la mutu avec sous rep, on est perdu si on se fie
+			// a spip.php qui est a la racine du spip, et vue qu'on sait pas se reperer
+			// s'en remettre a l'adresse du site. alea jacta est.
+			OR $ti!==_NOM_TEMPORAIRES_INACCESSIBLES){
+
+			if (isset($GLOBALS['meta']['adresse_site'])) {
+				$uri_ref = parse_url($GLOBALS['meta']['adresse_site']);
+				$uri_ref = $uri_ref['path'].'/';
+			}
+		  else
+			  $uri_ref = "";
+		}
+		if (!$uri OR !$uri_ref)
 			$GLOBALS['profondeur_url'] = 0;
 		else {
-			$GLOBALS['profondeur_url'] = max(0, 1+
+			$GLOBALS['profondeur_url'] = max(0,
 				substr_count($uri[0], '/')
-				- substr_count($GLOBALS['meta']['adresse_site'],'/'));
+				- substr_count($uri_ref,'/'));
 		}
 	}
 	// s'il y a un cookie ou PHP_AUTH, initialiser visiteur_session
@@ -1411,7 +1444,7 @@ function spip_initialisation_suite() {
 	define('_IMG_GD_MAX_PIXELS', (isset($GLOBALS['meta']['max_taille_vignettes'])&&$GLOBALS['meta']['max_taille_vignettes']<5500000)?$GLOBALS['meta']['max_taille_vignettes']:0);
 	define('_IMG_GD_QUALITE', 85);
 
-	@define('_MEMORY_LIMIT_MIN',16); // en Mo
+	if (!defined('_MEMORY_LIMIT_MIN')) define('_MEMORY_LIMIT_MIN', 16);
 	// si on est dans l'espace prive et si le besoin est superieur a 8Mo (qui est vraiment le standard)
 	// on verifie que la memoire est suffisante pour le compactage css+js pour eviter la page blanche
 	// il y aura d'autres problemes et l'utilisateur n'ira pas tres loin, mais ce sera plus comprehensible qu'une page blanche
@@ -1742,6 +1775,12 @@ function recuperer_fond($fond, $contexte=array(), $options = array(), $connect='
 
 	foreach(is_array($fond) ? $fond : array($fond) as $f){
 		$page = evaluer_fond($f, $contexte, $connect);
+		if ($page === '') {
+			$c = isset($options['compil']) ? $options['compil'] :'';
+			$a = array('fichier'=>$fond.'.'._EXTENSION_SQUELETTES);
+			erreur_squelette(_T('info_erreur_squelette2', $a), $c);
+		}
+					 
 		if (isset($options['ajax'])AND $options['ajax']){
 			include_spip('inc/filtres');
 			$page['texte'] = encoder_contexte_ajax(array_merge($contexte,array('fond'=>$f)),'',$page['texte']);
