@@ -3,7 +3,7 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2010                                                *
+ *  Copyright (c) 2001-2011                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
@@ -11,8 +11,8 @@
 \***************************************************************************/
 
 
-if (defined("_ECRIRE_INC_VERSION")) return;
-define("_ECRIRE_INC_VERSION", "1");
+if (defined('_ECRIRE_INC_VERSION')) return;
+define('_ECRIRE_INC_VERSION', "1");
 
 # masquer les eventuelles erreurs sur les premiers define
 error_reporting(E_ALL ^ E_NOTICE);
@@ -23,7 +23,8 @@ define('_EXTENSION_PHP', '.php3');
 #define('_EXTENSION_PHP', '');
 #mettre a true pour compatibilite PHP3
 define('_FEED_GLOBALS', false);
-
+# compat php < 5.1
+if (!isset($_SERVER['REQUEST_TIME'])) $_SERVER['REQUEST_TIME'] = time();
 
 # le nom du repertoire ecrire/
 define('_DIR_RESTREINT_ABS', 'ecrire/');
@@ -89,6 +90,12 @@ OR (_EXTENSION_PHP AND @file_exists($f = _ROOT_RESTREINT . _NOM_CONFIG . _EXTENS
 	define('_FILE_OPTIONS', $f);
 } else define('_FILE_OPTIONS', '');
 
+// les modules par defaut pour la traduction.
+// Constante utilisee par le compilateur et le decompilateur
+// sa valeur etant traitee par inc_traduire_dist
+
+define('MODULES_IDIOMES', 'public/spip/ecrire');
+
 // *** Fin des define *** //
 
 
@@ -284,6 +291,7 @@ $spip_pipeline = array(
 	'declarer_tables_principales'=>'',
 	'declarer_tables_auxiliaires'=>'',
 	'declarer_tables_objets_surnoms' => '',
+	'declarer_type_surnoms' => '',
 	'declarer_url_objets' => '',
 	'definir_session' => '',
 	'delete_tables' => '',
@@ -331,6 +339,7 @@ $spip_pipeline = array(
 	'calculer_rubriques' => '',
 	'autoriser' => '',
 	'notifications' => '',
+	'notifications_envoyer_mails' => '',
 	'editer_contenu_objet' => '',
 	'arbo_creer_chaine_url' => '|urls_arbo_creer_chaine_url',
 	'propres_creer_chaine_url' => '|urls_propres_creer_chaine_url',
@@ -401,7 +410,7 @@ $liste_des_authentifications = array(
 // numero de branche, utilise par les plugins
 // pour specifier les versions de SPIP necessaire
 // il faut s'en tenir a un nombre de decimales fixe ex : 2.0.0, 2.0.0-dev, 2.0.0-beta, 2.0.0-beta2
-$spip_version_branche = "2.1.1";
+$spip_version_branche = "2.1.12";
 // version des signatures de fonctions PHP
 // (= numero SVN de leur derniere modif cassant la compatibilite et/ou necessitant un recalcul des squelettes)
 $spip_version_code = 15375;
@@ -433,8 +442,8 @@ require_once _ROOT_RESTREINT . 'base/connect_sql.php';
 if (_FILE_OPTIONS) include_once _FILE_OPTIONS;
 
 // Masquer les warning
-@define('E_DEPRECATED',8192); // compatibilite PHP 5.3
-define('SPIP_ERREUR_REPORT',E_ALL ^ E_NOTICE ^ E_DEPRECATED);
+if (!defined('E_DEPRECATED')) define('E_DEPRECATED', 8192);
+define('SPIP_ERREUR_REPORT', E_ALL ^ E_NOTICE ^ E_DEPRECATED);
 error_reporting(SPIP_ERREUR_REPORT);
 
 // Initialisations critiques non surchargeables par les plugins
