@@ -3,7 +3,7 @@
 // extrait automatiquement de http://www.spip.net/trad-lang/
 // ** ne pas modifier le fichier **
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -748,6 +748,9 @@ D&eacute;i schons gebrauchten Sproochen (als &eacute;ischt ugewisen) k&euml;nnen
 'jour_non_connu_nc' => '?',
 
 // L
+'ldap_correspondance' => 'h&eacute;ritage du champ @champ@', # NEW
+'ldap_correspondance_1' => 'H&eacute;ritage des champs LDAP', # NEW
+'ldap_correspondance_2' => 'Pour chacun des champs SPIP suivants, indiquer le nom du champ LDAP correspondant. Laisser vide pour ne pas le remplir, s&eacute;parer par des espaces ou des virgules pour essayer plusieurs champs LDAP.', # NEW
 'lien_ajout_destinataire' => 'Destinataire derb&auml;i setzen',
 'lien_ajouter_auteur' => 'D&euml;sen Auteur derb&auml;i setzen',
 'lien_ajouter_participant' => 'E Mataarbechter derb&auml;i setzen',
@@ -791,7 +794,7 @@ D&eacute;i schons gebrauchten Sproochen (als &eacute;ischt ugewisen) k&euml;nnen
 'mois_non_connu' => 'onbekannt',
 
 // N
-'nouvelles_versions' => 'De nouvelles versions de SPIP sont disponibles', # NEW
+'nouvelle_version_spip' => 'La version @version@ de SPIP est disponible', # NEW
 
 // O
 'onglet_contenu' => 'Inhalt',
@@ -802,19 +805,6 @@ D&eacute;i schons gebrauchten Sproochen (als &eacute;ischt ugewisen) k&euml;nnen
 'onglet_proprietes' => 'Propri&eacute;t&eacute;iten',
 'onglet_repartition_actuelle' => 'elo',
 'onglet_sous_rubriques' => '&Euml;nner-Rubriken',
-'ortho_ajouter_ce_mot' => 'D&euml;st Wuert an den Dictionnaire derb&auml;i setzen',
-'ortho_aucune_suggestion' => 'Keng Suggestioun fonnt fir d&euml;st Wuert.',
-'ortho_avis_privacy' => 'En Orthographie-Korrektor ass a SPIP integr&eacute;ert. Ier dier d&euml;s Fonktionnalit&eacute;it aschalt, liest w.e.g. de n&auml;chsten Abschnit:',
-'ortho_avis_privacy2' => 'Fir d\'Orthographie vun engem Text ze kontroll&eacute;ieren, sch&eacute;ckt de Site d\'L&euml;scht vun de Wierder op en externen "Orthographie-Server" deen vun de Membere vun der SPIP-Communaut&eacute;it bereed gestalt g&euml;tt. D\'Wierder ginn duergerneen gesch&eacute;ckt fir e Minimum vun Vertraul&euml;chkeet ze garant&eacute;ieren. Wann dir &euml;m &auml;r Daten besuergt sidd, da schalt d&euml;s Optioun n&euml;t an (an huelt direkt &auml;r Informationen vum Internet erof).',
-'ortho_ce_mot_connu' => 'D&euml;st Wuert g&euml;t &euml;t am Dictionnaire vum Site.',
-'ortho_dico_absent' => 'Fir d&euml;s Sprooch gouf keen Dictionnaire fonnt.',
-'ortho_mode_demploi' => 'D&eacute;i onbekannte Wierder si roud mark&eacute;iert. Dir k&euml;nnt op all Wuert klicken fir Viirsch&eacute;i fir d\'Korrektur ze gesinn.',
-'ortho_mots_a_corriger' => 'Wierder ze verbesseren',
-'ortho_orthographe' => 'Orthographie',
-'ortho_supprimer_ce_mot' => 'D&euml;st Wuert aus dem Dictionnaire l&auml;schen',
-'ortho_trop_de_fautes' => 'Opgepasst: &auml;ren Text huet zevill Fehler, &euml;t g&euml;t keng Korrektur virgeschlo&euml;n fir de System n&euml;t ze iwwerlaaschten.',
-'ortho_verif_impossible' => 'De System kann d\'Orthographie vun d&euml;sem Text n&euml;t kontroll&eacute;ieren.',
-'ortho_verifier' => 'Orthographie kontroll&eacute;ieren',
 
 // P
 'page_pas_proxy' => 'D&euml;s S&auml;it d&auml;rf n&euml;t duerch de Proxy',
