@@ -3,7 +3,7 @@
 // extrait automatiquement de http://www.spip.net/trad-lang/
 // ** ne pas modifier le fichier **
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -790,6 +790,9 @@ een kleur geeft hun status aan&nbsp;:',
 'jour_non_connu_nc' => 'onbekend',
 
 // L
+'ldap_correspondance' => 'erfenis van het veld @champ@',
+'ldap_correspondance_1' => 'Erfenis van de velden LDAP',
+'ldap_correspondance_2' => 'Voor elk volgend SPIP veld, de naam van het overeenkomstige veld LDAP aangeven. Leegte laten om niet het te vullen, door ruimtes of komma\'s te scheiden om verschillende LDAP velden te proberen.',
 'lien_ajout_destinataire' => 'Voeg deze bestemmeling toe',
 'lien_ajouter_auteur' => 'Voeg deze auteur toe',
 'lien_ajouter_participant' => 'Voeg nieuwe deelnemer toe',
@@ -833,7 +836,7 @@ een kleur geeft hun status aan&nbsp;:',
 'mois_non_connu' => 'Onbekend',
 
 // N
-'nouvelles_versions' => 'De nouvelles versions de SPIP sont disponibles', # NEW
+'nouvelle_version_spip' => 'La version @version@ de SPIP est disponible', # NEW
 
 // O
 'onglet_contenu' => 'Inhoud',
@@ -844,19 +847,6 @@ een kleur geeft hun status aan&nbsp;:',
 'onglet_proprietes' => 'Eigendommen',
 'onglet_repartition_actuelle' => 'nu',
 'onglet_sous_rubriques' => 'Onder-rubrieken',
-'ortho_ajouter_ce_mot' => 'Dit woord aan het woordenboek toevoegen',
-'ortho_aucune_suggestion' => 'Voor dit woord hebben we geen enkele suggestie gevonden.',
-'ortho_avis_privacy' => 'Een spellingcontrole is toegevoegd aan SPIP. Vooraleer deze functie te activeren, raden we je aan de volgende paragraaf aandachtig te lezen&nbsp;:',
-'ortho_avis_privacy2' => 'Tijdens het uitvoeren van een spellingcontrole zal de site de te controleren woordenlijst verzenden naar een van de externe &laquo;&nbsp;spellingservers&nbsp;&raquo; die door verschillende leden van de SPIP-gemeenschap ter beschikking gesteld worden. De woorden worden in willekeurige volgorde verstuurd, dit om een minimum aan geheimhouding te waarborgen. Indien uw gegevens vertrouwelijk zijn, activeer deze functie dan niet (en haal uw gegevens ook van het internet).',
-'ortho_ce_mot_connu' => 'Dit woord staat in het woordenboek van de site.',
-'ortho_dico_absent' => 'Voor deze taal werd geen woordenboek gevonden',
-'ortho_mode_demploi' => 'Niet-herkende woorden zijn rood onderlijnd. Je kan een woord aanklikken om suggesties voor verbetering weer te geven.',
-'ortho_mots_a_corriger' => 'te verbeteren woorden',
-'ortho_orthographe' => 'Spelling',
-'ortho_supprimer_ce_mot' => 'Dit woord uit het woordenboek verwijderen',
-'ortho_trop_de_fautes' => 'Opgelet&nbsp;: uw tekst bevat veel schrijffouten. Correcties worden niet voorgesteld om het systeem niet te overbelasten.',
-'ortho_verif_impossible' => 'Het systeem kan de schrijfwijze van deze tekst niet controleren.',
-'ortho_verifier' => 'Schrijfwijze controleren',
 
 // P
 'page_pas_proxy' => 'Deze bladzijde moet niet via proxy gaan',
