@@ -3,7 +3,7 @@
 // extrait automatiquement de http://www.spip.net/trad-lang/
 // ** ne pas modifier le fichier **
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -653,7 +653,6 @@ D&#283;kujeme v&aacute;m za &uacute;&#269;ast
 'onglet_repartition_rubrique' => 'Rozd&#283;len&iacute; podle sekc&iacute;',
 'onglet_save_restaur_base' => 'Z&aacute;loha/obnova datab&aacute;ze',
 'onglet_vider_cache' => 'Vymazat mezipam&#283;t (cache)',
-'ortho_trop_de_fautes2' => 'Odstra&#328;te chyby patrn&eacute; na prvn&iacute; pohled a zkuste to znovu.',
 
 // P
 'pass_choix_pass' => 'Zadejte nov&eacute; heslo:',
