@@ -3,14 +3,14 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2010                                                *
+ *  Copyright (c) 2001-2011                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 /*--------------------------------------------------------------------- */
 /*	Gestion des MAJ par tableau indexe par le numero SVN du chgt	*/
@@ -242,4 +242,7 @@ $GLOBALS['maj'][15676] = array(array('upgrade_types_documents'));
 // Type de fichiers : webm http://en.wikipedia.org/wiki/Flv#File_formats
 $GLOBALS['maj'][15827] = array(array('upgrade_types_documents'));
 
+// IP en 40 caracteres pour IP v6
+$GLOBALS['maj'][15828] = array(array('sql_alter',"TABLE spip_forum CHANGE `ip` `ip` VARCHAR(40) DEFAULT '' NOT NULL"));
+
 ?>
