@@ -3,14 +3,14 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2010                                                *
+ *  Copyright (c) 2001-2011                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 include_spip('inc/charsets');
 include_spip('inc/texte');
 include_spip('inc/plugin'); // pour charge_instal_plugin
@@ -51,10 +51,13 @@ function plugins_afficher_plugin_dist($url_page, $plug_file, $actif, $expose=fal
 
 function plugin_bouton_config($nom, $infos, $dir)
 {
+	// la verification se base sur le filesystem
+	// il faut donc n'utiliser que des minuscules, par convention
+	$prefix = strtolower($infos['prefix']);
 	// si plugin.xml fournit un squelette, le prendre
 	if ($infos['config'])
 		return recuperer_fond("$dir$nom/" . $infos['config'],
-				array('script' => 'configurer_' . $infos['prefix'],
+				array('script' => 'configurer_' . $prefix,
 					'nom' => $nom));
 
 	// si le plugin CFG est la, l'essayer
@@ -65,8 +68,8 @@ function plugin_bouton_config($nom, $infos, $dir)
 	}
 
 	// sinon prendre le squelette std sur le nom std
-	return recuperer_fond("prive/cfg",
-			array('script' => 'configurer_' . $infos['prefix'],
+	return recuperer_fond("prive/modeles/cfg",
+			array('script' => 'configurer_' . $prefix,
 				'nom' => $nom));
 }
 
@@ -139,11 +142,6 @@ function plugin_etat_en_clair($etat){
 function plugin_propre($texte) {
 	$mem = $GLOBALS['toujours_paragrapher'];
 	$GLOBALS['toujours_paragrapher'] = false;
-	$regexp = "|\[:([^>]*):\]|";
-	if (preg_match_all($regexp, $texte, $matches, PREG_SET_ORDER))
-	foreach ($matches as $regs)
-		$texte = str_replace($regs[0],
-		_T('spip/ecrire/public:'.$regs[1]), $texte);
 	$texte = propre($texte);
 	$GLOBALS['toujours_paragrapher'] = $mem;
 	return $texte;
