@@ -3,16 +3,16 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2010                                                *
+ *  Copyright (c) 2001-2011                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
-@define('_CONTEXTE_IGNORE_VARIABLES',"/(^var_|^PHPSESSID$)/");
+if (!defined('_CONTEXTE_IGNORE_VARIABLES')) define('_CONTEXTE_IGNORE_VARIABLES', "/(^var_|^PHPSESSID$)/");
 //
 // calcule la page et les entetes
 // determine le contexte donne par l'URL (en tenant compte des reecritures) 
@@ -97,8 +97,7 @@ function assembler($fond, $connect='') {
 					AND $url !== $url_redirect) {
 						spip_log("Redirige $url vers $url_redirect");
 						include_spip('inc/headers');
-						http_status(301);
-						redirige_par_entete($url_redirect);
+						redirige_par_entete($url_redirect, '', 301);
 					}
 					if (isset($nfond))
 						$fond = $nfond;
@@ -128,6 +127,9 @@ function assembler($fond, $connect='') {
 			// produire la page : peut mettre a jour $lastmodified
 			$produire_page = charger_fonction('produire_page','public');
 			$page = $produire_page($fond, $GLOBALS['contexte'], $use_cache, $chemin_cache, NULL, $page, $lastmodified, $connect);
+			if ($page === '')
+				erreur_squelette(_T('info_erreur_squelette2',
+					array('fichier'=>htmlspecialchars($fond).'.'._EXTENSION_SQUELETTES)));
 		}
 
 		if ($page AND $chemin_cache) $page['cache'] = $chemin_cache;
@@ -214,6 +216,8 @@ function calculer_contexte_implicite(){
 	$contexte_implicite = array(
 		'squelettes' => $GLOBALS['dossier_squelettes'], // devrait etre 'chemin' => $GLOBALS['path_sig'], ?
 		'host' => $_SERVER['HTTP_HOST'],
+		'https' => $_SERVER['HTTPS'],
+		'espace' => test_espace_prive(),
 		'marqueur' => (isset($GLOBALS['marqueur']) ?  $GLOBALS['marqueur'] : ''),
 		'notes' => $notes('','contexter_cache'),
 	);
@@ -312,8 +316,6 @@ function inserer_balise_dynamique($contexte_exec, $contexte_compil)
 	if (!is_array($contexte_exec))
 		echo $contexte_exec; // message d'erreur etc
 	else {
-		if ($contexte_compil[4] AND empty($contexte_exec[2]['lang']))
-			$contexte_exec[2]['lang'] = $contexte_compil[4];
 		inclure_balise_dynamique($contexte_exec, true, $contexte_compil);
 	}
 }
@@ -573,8 +575,7 @@ function inclure_modele($type, $id, $params, $lien, $connect='') {
 		$retour = inserer_attribut($retour, 'class',
 			trim(str_replace(' spip_lien_ok ', ' ', " $classes ")));
 	} else if ($lien)
-		$retour = "<a href='".$lien[0]."' class='".$lien[1]."'>".$retour."</a>";
-
+		$retour = "<a href='".$lien['href']."' class='".$lien['class']."'>".$retour."</a>";
 	$compteur--;
 
 	return  (isset($arg_list['ajax'])AND $arg_list['ajax']=='ajax')
@@ -664,8 +665,12 @@ function page_base_href(&$texte){
 			include_spip('inc/filtres_mini');
 			// ajouter un base qui reglera tous les liens relatifs
 			$base = url_absolue('./');
+			$bbase = "\n<base href=\"$base\" />";
 			if (($pos = strpos($head, '<head>')) !== false)
-				$head = substr_replace($head, "\n<base href=\"$base\" />", $pos+6, 0);
+				$head = substr_replace($head, $bbase, $pos+6, 0);
+			elseif(preg_match(",<head[^>]*>,i",$head,$r)){
+				$head = str_replace($r[0], $r[0].$bbase, $head);
+			}
 			$texte = $head . substr($texte,$poshead);
 			// gerer les ancres
 			$base = $_SERVER['REQUEST_URI'];
