@@ -3,7 +3,7 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2010                                                *
+ *  Copyright (c) 2001-2011                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
@@ -17,7 +17,7 @@
 // elle recoit en entree un objet de classe CHAMP, le modifie et le retourne.
 // Cette classe est definie dans public/interfaces
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 // http://doc.spip.org/@interprete_argument_balise
 function interprete_argument_balise($n,$p) {
@@ -500,7 +500,7 @@ function balise_PAGINATION_dist($p, $liste='true') {
 	// s'il n'y a pas de nom de boucle, on ne peut pas paginer
 	if ($b === '') {
 		$msg = array('zbug_champ_hors_boucle',
-			array('champ' => $liste ? 'PAGINATION' : 'ANCRE_PAINATION')
+			array('champ' => $liste ? 'PAGINATION' : 'ANCRE_PAGINATION')
 			  );
 		erreur_squelette($msg, $p);
 		return $p;
@@ -1374,4 +1374,4 @@ function balise_BOUTON_ACTION_dist($p){
 	return $p;
 }
 
-?>
\ No newline at end of file
+?>
