@@ -3,14 +3,14 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2010                                                *
+ *  Copyright (c) 2001-2011                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 //
 // Le format souhaite : "a/bout-d-url.md5" (.gz s'ajoutera pour les gros caches)
@@ -265,18 +265,6 @@ function public_cacher_dist($contexte, &$use_cache, &$chemin_cache, &$page, &$la
 		return;
 	}
 
-	// Faut-il effacer des pages invalidees (en particulier ce cache-ci) ?
-	if (isset($GLOBALS['meta']['invalider'])) {
-		// ne le faire que si la base est disponible
-		if (spip_connect()) {
-			include_spip('inc/invalideur');
-			retire_caches($chemin_cache); # API invalideur inutile
-			supprimer_fichier(_DIR_CACHE.$chemin_cache);
-			if ($chemin_cache_session)
-				supprimer_fichier(_DIR_CACHE.$chemin_cache_session);
-		}
-	}
-
 	// Si un calcul, recalcul [ou preview, mais c'est recalcul] est demande,
 	// on supprime le cache
 	if ($GLOBALS['var_mode'] &&
