@@ -3,19 +3,18 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2010                                                *
+ *  Copyright (c) 2001-2011                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-
 //
 // Fichier principal du compilateur de squelettes
 //
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 // reperer un code ne calculant rien, meme avec commentaire
 define('CODE_MONOTONE', ",^(\n//[^\n]*\n)?\(?'([^'])*'\)?$,");
@@ -646,9 +645,9 @@ function compile_cas($tableau, $descr, &$boucles, $id_boucle) {
 		case 'idiome':
 			$l = array();
 			foreach ($p->arg as $k => $v) {
-				if ($k) $l[]=$k.' => '.calculer_liste($v,$p->descr,$boucles,$id_boucle);
+			  if ($k) $l[]= _q($k).' => '.calculer_liste($v,$descr,$boucles,$id_boucle);
 			}
-			$l = !$l ? '' : (",array(".implode(', ',$l).")");
+			$l = !$l ? '' : (", array(".implode(",\n",$l).")");
 			$code = "_T('" . $p->module . ":" .$p->nom_champ . "'$l)";
 			if ($p->param) {
 				$p->id_boucle = $id_boucle;
@@ -897,9 +896,7 @@ function compiler_squelette($squelette, $boucles, $nom, $descr, $sourcefile, $co
 		$id = strval($id); // attention au type dans index_pile
 		$type = $boucle->type_requete;
 		if ($type AND $type != 'boucle') {
-			if ($boucle->param) {
-				$res = calculer_criteres($id, $boucles);
-			}
+			$crit = !$boucle->param ? true : calculer_criteres($id, $boucles);
 			$descr['id_mere'] = $id;
 			$boucles[$id]->return =
 			  calculer_liste($boucle->milieu,
@@ -909,7 +906,7 @@ function compiler_squelette($squelette, $boucles, $nom, $descr, $sourcefile, $co
 			// Si les criteres se sont mal compiles
 			// ne pas tenter d'assembler le code final
 			// (mais compiler le corps pour detection d'erreurs)
-			if (is_array($res))
+			if (is_array($crit))
 				$boucles[$id]->type_requete = false;
 		}
 	}
