@@ -3,14 +3,14 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2010                                                *
+ *  Copyright (c) 2001-2011                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 include_spip('inc/texte');
 include_spip('inc/documents');
@@ -285,7 +285,7 @@ function filtre_introduction_dist($descriptif, $texte, $longueur, $connect) {
 	$texte = propre($texte,$connect);
 	$notes('','depiler');
 
-	@define('_INTRODUCTION_SUITE', '&nbsp;(...)');
+	if (!defined('_INTRODUCTION_SUITE')) define('_INTRODUCTION_SUITE', '&nbsp;(...)');
 	$texte = couper($texte, $longueur, _INTRODUCTION_SUITE);
 
 	return $texte;
@@ -509,6 +509,10 @@ function calculer_select ($select = array(), $from = array(),
 			$menage = true;
 		}
 	}
+
+	// evacuer les eventuels groupby vide issus d'un calcul dynamique
+	$groupby = array_diff($groupby,array(''));
+
 	// remplacer les sous requetes recursives au calcul
 	list($where_simples,$where_sous) = trouver_sous_requetes($where);
 	//var_dump($where_sous);
@@ -655,8 +659,7 @@ function calculer_select ($select = array(), $from = array(),
 	  }
 	  $from = reinjecte_joint($afrom, $from);
 	}
-
-	$GLOBALS['debug']['aucasou'] = array ($table, $id, $serveur);
+	$GLOBALS['debug']['aucasou'] = array ($table, $id, $serveur, $requeter);
 	$r = sql_select($select, $from, $where,
 		$groupby, array_filter($orderby), $limit, $having, $serveur, $requeter);
 	unset($GLOBALS['debug']['aucasou']);
