@@ -3,7 +3,7 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2010                                                *
+ *  Copyright (c) 2001-2011                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
@@ -20,7 +20,7 @@
 
 define('_CODE_QUOTE', ",^(\n//[^\n]*\n)? *'(.*)' *$,");
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 // {racine}
 // http://www.spip.net/@racine
@@ -190,10 +190,16 @@ function critere_recherche_dist($idb, &$boucles, $crit) {
 	else
 		$quoi = '@$Pile[0]["recherche"]';
 
+	// indiquer si l'on est dans une boucle forum avec le critère {plat} ou {tout}
+	$plat = "false" ;
+	if (isset($boucle->modificateur['tout']) OR isset($boucle->modificateur['plat'])) {
+		$plat = "true" ;
+	}	
+		
 	$boucle->hash .= '
 	// RECHERCHE
 	$prepare_recherche = charger_fonction(\'prepare_recherche\', \'inc\');
-	list($rech_select, $rech_where) = $prepare_recherche('.$quoi.', "'.$boucle->id_table.'", "'.$crit->cond.'","' . $boucle->sql_serveur . '");
+	list($rech_select, $rech_where) = $prepare_recherche('.$quoi.', "'.$boucle->id_table.'", "'.$crit->cond.'","' . $boucle->sql_serveur . '", "'.$plat.'");
 	';
 
 	$t = $boucle->id_table . '.' . $boucle->primary;
@@ -650,7 +656,8 @@ function calculer_parties(&$boucles, $id_boucle, $debut, $mode) {
 		// {pagination}, gerer le debut_xx=-1 pour tout voir
 		if ($op1 == 'p') {
 			$debut .= ";\n	\$debut_boucle = ((\$tout=(\$debut_boucle == -1))?0:(\$debut_boucle))";
-			$fin = "(\$tout ? \$Numrows['$id_boucle']['total'] : $fin)";
+			$debut .= ";\n	\$debut_boucle = max(0,min(\$debut_boucle,floor(($nombre_boucle-1)/($total_parties))*($total_parties)))";
+			$fin = "(\$tout ? $nombre_boucle : $fin)";
 		}
 	}
 
@@ -855,7 +862,7 @@ function calculer_critere_DEFAUT_args($idb, &$boucles, $crit, $args)
 		  $where = array("'?'", "(is_array($pred))", 
 				 critere_IN_cas ($idb, $boucles, 'COND', $arg, $op, array($pred), $col), 
 				 $where);
-		$where = array("'?'", "!$pred","''", $where);
+		$where = array("'?'", "!(is_array($pred)?count($pred):strlen($pred))","''", $where);
 		if ($where_complement) // condition annexe du type "AND (objet='article')"
 			$where_complement = array("'?'", "!$pred","''", $where_complement);
 	}
@@ -984,6 +991,7 @@ function calculer_critere_infixe_externe(&$boucle, $crit, $op, $desc, $col, $col
 	// gestion par les plugins des jointures tordues 
 	// pas automatiques mais necessaires
 	if (is_array($exceptions_des_jointures[$table])) {
+
 		$t = $exceptions_des_jointures[$table];
 		$index = isset($t[$col])
 		?  $t[$col] : (isset($t['']) ? $t[''] : array());
@@ -992,11 +1000,14 @@ function calculer_critere_infixe_externe(&$boucle, $crit, $op, $desc, $col, $col
 			list($t, $col, $calculer_critere_externe) = $index;
 		elseif (count($index)==2)
 			list($t, $col) = $t[$col];
-		else 	{
+		elseif (count($index)==1){
 			list($calculer_critere_externe) = $index;
 			$t = $table;
 		}
-	} else if (isset($exceptions_des_jointures[$col]))
+		else
+			$t=''; // jointure non declaree. La trouver.
+	}
+	elseif (isset($exceptions_des_jointures[$col]))
 		list($t, $col) = $exceptions_des_jointures[$col];
 	else $t =''; // jointure non declaree. La trouver.
 
