@@ -3,14 +3,14 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2010                                                *
+ *  Copyright (c) 2001-2011                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 include_spip('public/decompiler');
 
@@ -52,20 +52,9 @@ function public_debusquer_dist($message='', $lieu='') {
 
 	// Erreur ou appel final ?
 	if ($message) {
-	  // Message a composer ?
-		if (is_array($message)) {
-			if (!is_numeric($message[0]))
-			  // message avec argument: instancier
-			  $message = _T($message[0], $message[1], 'spip-debug-arg');
-			else {
-			  // message SQL: interpreter
-			  $message = debusquer_requete($message);
-			}
-		}
-
+		$message = debusquer_compose_message($message);
 		$tableau_des_erreurs[] = array($message, $lieu);
 		set_request('var_mode', 'debug');
-		spip_log("Debug: " . $message . " (" . $GLOBALS['fond'] .")" );
 		$GLOBALS['bouton_admin_debug'] = true;
 		// Permettre a la compil de continuer
 		if (is_object($lieu) AND !$lieu->code)
@@ -77,7 +66,6 @@ function public_debusquer_dist($message='', $lieu='') {
 	if (empty($debug_objets['principal'])) 
 		$debug_objets['principal'] = $GLOBALS['fond'];
 
-
 	include_spip('inc/autoriser');
 	if (!autoriser('debug')) return;
 	include_spip('inc/headers');
@@ -115,13 +103,29 @@ function public_debusquer_dist($message='', $lieu='') {
 		if (!$fonc) $fonc = $debug_objets['principal'];
 		$titre = !$mode ? $fonc : ($mode . ' ' . $debug_objets['sourcefile'][$fonc]);
 	}
-	if ($message===false)
+	if ($message===false) {
+		lang_select();
 		return debusquer_entete($titre, $res);
+	}
 	else
 		echo debusquer_entete($titre, $res);
 	exit;
 }
 
+function debusquer_compose_message($msg)
+{
+	if (is_array($msg)) {
+		if (!is_numeric($msg[0]))
+			// message avec argument: instancier
+			$msg = _T($msg[0], $msg[1], 'spip-debug-arg');
+		else
+			// message SQL: interpreter
+			$msg = debusquer_requete($msg);
+	}
+	spip_log("Debug: " . $msg . " (" . $GLOBALS['fond'] .")" );
+	return $msg;
+}
+
 function debusquer_bandeau($erreurs) {
 
 	if (!empty($erreurs)) {
@@ -161,31 +165,33 @@ function debusquer_navigation($tableau, $caption='', $id='debug-nav') {
 	$res = '';
 	$href = quote_amp(parametre_url($GLOBALS['REQUEST_URI'], 'var_mode', 'debug'));
 	foreach ($tableau as $i => $err) {
-		$boucle = $ligne = $skel = "&nbsp;&nbsp;&nbsp;/&nbsp;&nbsp;";
+		$boucle = $ligne = $skel = '';
 		list($msg, $lieu) = $err;
 		if (is_object($lieu)) {
 			$ligne = $lieu->ligne;
-			if ($lieu->id_boucle) $boucle =  $lieu->id_boucle;
+			$boucle = $lieu->id_boucle ? $lieu->id_boucle : '';
 			if (isset($lieu->descr['nom'])) {
 				$nom_code = $lieu->descr['nom'];
 				$skel = $lieu->descr['sourcefile'];
-			} else $skel = $nom_code = '';
-			$h = parametre_url($href, 'var_mode_affiche', 'squelette');
-			$h = parametre_url($h, 'var_mode_objet', $nom_code);
-			$h .= '#L' . $ligne;
-		} else 	{$h = $href . "#spip-debug"; $boucle = $lieu;}
+				$h2 = parametre_url($href, 'var_mode_objet', $nom_code);
+				$h3 = parametre_url($h2, 'var_mode_affiche', 'squelette') . '#L' . $ligne;
+				$skel = "<a href='$h3'><b>$skel</b></a>";
+				if ($boucle) {
+					$h3 = parametre_url($h2.$boucle, 'var_mode_affiche', 'boucle');
+					$boucle = "<a href='$h3'><b>$boucle</b></a>";
+				}
+			}
+		}
 
 		$j = ($i+1); 
-		$res .= "<tr id='req$j'><td style='text-align: right'><a href='"
-		. $h
-		. "'><b>"
+		$res .= "<tr id='req$j'><td style='text-align: right'>"
 		. $j
-		. "&nbsp;</b></a>\n</td><td style='text-align: left'>"
+		. "&nbsp;</td><td style='text-align: left'>"
 		. $msg
 		. "</td><td style='text-align: left'>"
-		. $skel
+		. ($skel ? $skel : "&nbsp;&nbsp;&nbsp;/&nbsp;&nbsp;")
 		. "</td><td class='spip-debug-arg' style='text-align: left'>"
-		. $boucle
+		. ($boucle ? $boucle : "&nbsp;&nbsp;&nbsp;/&nbsp;&nbsp;")
 		. "</td><td style='text-align: right'>"
 		. $ligne
 		.  "</td></tr>\n";
@@ -219,7 +225,6 @@ function debusquer_navigation($tableau, $caption='', $id='debug-nav') {
 //
 
 function debusquer_requete($message) {
-
 	list($errno, $msg, $query) = $message;
 	if (preg_match(',err(no|code):?[[:space:]]*([0-9]+),i', $msg, $regs))
 	  {
@@ -247,7 +252,7 @@ function debusquer_requete($message) {
 		. "\n<br /><span style='color: red'><b>"
 		. htmlspecialchars($query)
 		. "</b></span></tt><br />"
-		. aide('erreur_mysql');
+		;//. aide('erreur_mysql');
 
 	return $err;
 }
@@ -432,13 +437,14 @@ function debusquer_squelette ($fonc, $mode, $self) {
 		$legend = _T('validation') . ' ' . $err;
 		$res = $id = '';
 	}
-	return "<div id='spip-debug'>$res"
+	return !trim($texte) ? '' : (
+		"<div id='spip-debug'>$res"
 		. "<div id='debug_boucle'><fieldset$id><legend>"
 		. $legend
 		. "</legend>"
 		. $texte
 		. "</fieldset></div>"
-		. "</div>";
+		. "</div>");
 }
 
 function debusquer_navigation_squelettes($self)
@@ -531,7 +537,7 @@ function debusquer_source($objet, $affiche)
 		$legend = $nom;
 		$req = $GLOBALS['debug_objets']['requete'][$objet];
 		if (function_exists('traite_query')) {
-		  $c = _request('connect');
+		  $c = strtolower(_request('connect'));
 		  $c = $GLOBALS['connexions'][$c ? $c : 0]['prefixe'];
 		  $req = traite_query($req,'', $c);
 		}
@@ -585,6 +591,7 @@ function debusquer_entete($titre, $corps)
 	global $debug_objets;
 	include_spip('balise/formulaire_admin');
 	include_spip('public/assembler'); // pour inclure_balise_dynamique
+	include_spip('inc/texte'); // pour corriger_typo
 
 	return _DOCTYPE_ECRIRE .
 	  html_lang_attributes() .
