@@ -3,7 +3,7 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2010                                                *
+ *  Copyright (c) 2001-2011                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
@@ -11,7 +11,7 @@
 \***************************************************************************/
 
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 # Ce fichier transforme un squelette en un tableau d'objets de classe Boucle
 # il est charge par un include calcule 
@@ -126,15 +126,15 @@ function phraser_idiomes($texte,$ligne,$result) {
 		$texte = substr($texte,$p+strlen($match[0]));
 		// Stocker les arguments de la balise de traduction
 		$args=array();
-		$vals=explode(',',$match[5]);
+		$vals=preg_split('/,\s*/',$match[5]);
 		foreach ($vals as $val) {
-			$arg=explode('=',$val);
+			$arg=preg_split('/\s*=/',$val);
 			if ($arg[0])
-				$args[$arg[0]]=phraser_champs($arg[1], 0, $_arg);	
+			  $args[$arg[0]]=phraser_champs($arg[1], 0, array());	
 		}
 		$champ->arg=$args;
 		$champ->nom_champ = strtolower($match[3]);
-		$champ->module = $match[2] ? $match[2] : 'public/spip/ecrire';
+		$champ->module = $match[2] ? $match[2] : MODULES_IDIOMES;
 		// pas d'imbrication pour les filtres sur langue
 		phraser_args(@$match[7], ":", '', array(), $champ);
 		$result[] = $champ;
