@@ -3,14 +3,14 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2010                                                *
+ *  Copyright (c) 2001-2011                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 //
 // Fonctions d'appel aux serveurs SQL presentes dans le code compile
@@ -73,13 +73,14 @@ function quete_profondeur($id, $connect='') {
 
 
 # retourne la date a laquelle comparer lorsqu'il y a des post-dates
+# cette date doit etre stable, de maniere a beneficier du query cache
+# du serveur SQL
 // http://doc.spip.org/@quete_date_postdates
 function quete_date_postdates() {
-	return
-	  date('Y-m-d H:i:s',
-	       ($GLOBALS['meta']['date_prochain_postdate'] > time())
-			? $GLOBALS['meta']['date_prochain_postdate']
-	       : (time()+(3600*24*10000))) ;
+	if ($GLOBALS['meta']['date_prochain_postdate'] > time())
+		return date('Y-m-d H:i:s', $GLOBALS['meta']['date_prochain_postdate']);
+	else
+		return '2138-01-01 00:00:00';
 }
 
 
@@ -311,4 +312,4 @@ function quete_debut_pagination($primary,$valeur,$pas,$res,$serveur=''){
 	// sinon, calculer le bon numero de page
 	return floor($pos/$pas)*$pas;
 }
-?>
\ No newline at end of file
+?>
