@@ -3,14 +3,14 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2010                                                *
+ *  Copyright (c) 2001-2011                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 // http://doc.spip.org/@trace_query_start
 function trace_query_start()
@@ -26,13 +26,12 @@ function trace_query_start()
 }
 
 // http://doc.spip.org/@trace_query_end
-function trace_query_end($query, $start, $result, $serveur='')
-{
+function trace_query_end($query, $start, $result, $erreur, $serveur=''){
 	if ($start)
 		trace_query_chrono($start, microtime(), $query, $result, $serveur);
 	// tracer les erreurs, sauf pour select, c'est fait dans abstract_sql
-	if ($err = sql_errno() AND !preg_match('/^select\b/i', $query))
-		erreur_squelette(array(sql_errno(), sql_error(), $query));
+	if ($erreur AND !preg_match('/^select\b/i', $query))
+		erreur_squelette(array(sql_errno($serveur), $erreur, $query));
 	return $result;
 }
 
@@ -44,14 +43,14 @@ function trace_query_chrono($m1, $m2, $query, $result, $serveur='')
 
 	$x = _request('var_mode_objet');
 	if (isset($GLOBALS['debug']['aucasou'])) {
-		list(, $boucle, $serveur) = $GLOBALS['debug']['aucasou'];
+		list(, $boucle, $serveur, $contexte) = $GLOBALS['debug']['aucasou'];
 		if ($x AND !preg_match("/$boucle\$/", $x))
 			return;
 		if ($serveur) $boucle .= " ($serveur)";
 		$boucle = "<b>$boucle</b>";
 	} else {
 		if ($x) return;
-		$boucle = '';
+		$boucle = $contexte = '';
 	}
 
 	list($usec, $sec) = explode(" ", $m1);
@@ -63,7 +62,7 @@ function trace_query_chrono($m1, $m2, $query, $result, $serveur='')
 	$q = preg_replace('/([a-z)`])\s+([A-Z])/', "$1\n<br />$2",htmlentities($query));
 	$e =  sql_explain($query, $serveur);
 	$r = str_replace('Resource id ','',(is_object($result)?get_class($result):$result));
-	$tableau_des_temps[] = array($dt, $nb, $boucle, $q, $e, $r);
+	$tableau_des_temps[] = array($dt, $nb, $boucle, $q, $e, $r, $contexte);
 }
 
 
@@ -73,18 +72,24 @@ function chrono_requete($temps)
 	$hors = "<i>" . _T('zbug_hors_compilation') . "</i>";
 	$t = $q = $n = $d = array();
 	// Totaliser les temps et completer le Explain
-	foreach ($temps as $key => $row) {
-		list($dt, $nb, $boucle, $query, $explain, $res) = $row;
+	foreach ($temps as $key => $v) {
+		list($dt, $nb, $boucle, $query, $explain, $res, $contexte) = $v;
+		if (is_array($contexte)) {
+			$k = ($contexte[0] . " $boucle");
+			include_spip('public/compiler');
+			$env = reconstruire_contexte_compil($contexte);
+		} else $k = $env = $boucle;
+
 		$total += $dt;
 		$t[$key] = $dt;
 		$q[$key] = $nb;
-		$d[$boucle]+= $dt;
-		if  ($boucle) @++$n[$boucle];
+		$d[$k]+= $dt;
+		if ($k) @++$n[$k];
 
 		if (!is_array($explain))
 			$explain = array();
-		foreach($explain as $k => $v) {
-			$explain[$k] = "<tr><th>$k</th><td>"
+		foreach($explain as $j => $v) {
+			$explain[$j] = "<tr><th>$j</th><td>"
 			  . str_replace(';','<br />',$v)
 			  . "</td></tr>";
 		}
@@ -98,7 +103,7 @@ function chrono_requete($temps)
 		. join('', $explain)
 		. "</table>";
 
-		$temps[$key] = array($e, $boucle);
+		$temps[$key] = array($e, $env, $k);
 	}
 	// Trier par temps d'execution decroissant
 	array_multisort($t, SORT_DESC, $q, $temps);
@@ -107,13 +112,13 @@ function chrono_requete($temps)
 	$t = array();
 	// Fabriquer les liens de navigations dans le tableau des temps
 	foreach($temps as $k => $v) {
-		$titre = textebrut(preg_replace(',</tr>,', "\n",$v[0]));
+		$titre = strip_tags($v[2]);
 		$href = quote_amp($GLOBALS['REQUEST_URI'])."#req$i";
 
-		$t[$v[1]][]= "<span class='spip-debug-arg'> "
+		$t[$v[2]][]= "<span class='spip-debug-arg'> "
 		. "<a title='$titre' href='$href'>$i</a>"
 		. '</span>'
-		. ((count($t[$v[1]]) % 10 == 9) ?  "<br />" : '');
+		. ((count($t[$v[2]]) % 10 == 9) ?  "<br />" : '');
 		$i++;
 	}
 
