@@ -3,14 +3,14 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2010                                                *
+ *  Copyright (c) 2001-2011                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 define('_DEFAULT_DB', 'spip');
 
@@ -24,7 +24,7 @@ define('_DEFAULT_DB', 'spip');
 // http://doc.spip.org/@req_pg_dist
 function req_pg_dist($addr, $port, $login, $pass, $db='', $prefixe='') {
 	static $last_connect = array();
-	charger_php_extension('pgsql');
+	if (!charger_php_extension('pgsql')) return false;
 	
 	// si provient de selectdb
 	if (empty($addr) && empty($port) && empty($login) && empty($pass)){
@@ -107,7 +107,7 @@ $GLOBALS['spip_pg_functions_1'] = array(
 // http://doc.spip.org/@spip_pg_trace_query
 function spip_pg_trace_query($query, $serveur='')
 {
-	$connexion = &$GLOBALS['connexions'][$serveur ? $serveur : 0];
+	$connexion = &$GLOBALS['connexions'][$serveur ? strtolower($serveur) : 0];
 	$prefixe = $connexion['prefixe'];
 	$link = $connexion['link'];
 	$db = $connexion['db'];
@@ -120,7 +120,9 @@ function spip_pg_trace_query($query, $serveur='')
 	$connexion['last'] = $query;
 	$r = spip_pg_query_simple($link, $query);
 
-	return $t ? trace_query_end($query, $t, $r, $serveur) : $r;
+	if ($e = spip_pg_errno($serveur))	// Log de l'erreur eventuelle
+		$e .= spip_pg_error($query, $serveur); // et du fautif
+	return $t ? trace_query_end($query, $t, $r, $e, $serveur) : $r;
 }
 
 // Fonction de requete generale quand on est sur que c'est SQL standard.
@@ -129,7 +131,7 @@ function spip_pg_trace_query($query, $serveur='')
 // http://doc.spip.org/@spip_pg_query
 function spip_pg_query($query, $serveur='',$requeter=true)
 {
-	$connexion = $GLOBALS['connexions'][$serveur ? $serveur : 0];
+	$connexion = &$GLOBALS['connexions'][$serveur ? strtolower($serveur) : 0];
 	$prefixe = $connexion['prefixe'];
 	$link = $connexion['link'];
 	$db = $connexion['db'];
@@ -388,7 +390,7 @@ function spip_pg_create_index($nom, $table, $champs, $serveur='', $requeter=true
 // http://doc.spip.org/@spip_pg_explain
 function spip_pg_explain($query, $serveur='',$requeter=true){
 	if (strpos(ltrim($query), 'SELECT') !== 0) return array();
-	$connexion = $GLOBALS['connexions'][$serveur ? $serveur : 0];
+	$connexion = &$GLOBALS['connexions'][$serveur ? strtolower($serveur) : 0];
 	$prefixe = $connexion['prefixe'];
 	$link = $connexion['link'];
 	if (preg_match('/\s(SET|VALUES|WHERE)\s/i', $query, $regs)) {
@@ -406,7 +408,7 @@ function spip_pg_explain($query, $serveur='',$requeter=true){
 function spip_pg_selectdb($db, $serveur='',$requeter=true) {
 	// se connecter a la base indiquee
 	// avec les identifiants connus
-	$index = $serveur ? $serveur : 0;
+	$index = $serveur ? strtolower($serveur) : 0;
 
 	if ($link = spip_connect_db('', '', '', '', $db, 'pg', '', '')){
 		if (($db==$link['db']) && $GLOBALS['connexions'][$index] = $link)
@@ -419,7 +421,7 @@ function spip_pg_selectdb($db, $serveur='',$requeter=true) {
 
 // http://doc.spip.org/@spip_pg_listdbs
 function spip_pg_listdbs($serveur) {
-	$connexion = $GLOBALS['connexions'][$serveur ? $serveur : 0];
+	$connexion = &$GLOBALS['connexions'][$serveur ? strtolower($serveur) : 0];
 	$link = $connexion['link'];
 	return spip_pg_query_simple($link, "select * From pg_database");
 }
@@ -429,7 +431,7 @@ function spip_pg_select($select, $from, $where='',
 			$groupby=array(), $orderby='', $limit='',
                            $having='', $serveur='',$requeter=true){
 
-	$connexion = $GLOBALS['connexions'][$serveur ? $serveur : 0];
+	$connexion = &$GLOBALS['connexions'][$serveur ? strtolower($serveur) : 0];
 	$prefixe = $connexion['prefixe'];
 	$link = $connexion['link'];
 	$db = $connexion['db'];
@@ -554,8 +556,6 @@ function spip_pg_frommysql($arg)
 			    'CAST(substring(\1, \'^ *[0-9]+\') as int)',
 			    $res);
 
-	$res = preg_replace('/FROM_UNIXTIME/i', 'ABSTIME', $res);
-
 	$res = preg_replace('/UNIX_TIMESTAMP\s*[(]\s*[)]/',
 			    ' EXTRACT(epoch FROM NOW())', $res);
 	
@@ -563,11 +563,10 @@ function spip_pg_frommysql($arg)
 	// il faut donc forcer les types en text (cas de md5(id_article))
 	$res = preg_replace('/md5\s*[(]([^)]*)[)]/i',
 			    'MD5(CAST(\1 AS text))', $res);
-											
+
 	$res = preg_replace('/UNIX_TIMESTAMP\s*[(]([^)]*)[)]/',
 			    ' EXTRACT(epoch FROM \1)', $res);
 
-
 	$res = preg_replace('/\bDAYOFMONTH\s*[(]([^()]*([(][^()]*[)][^()]*)*[^)]*)[)]/',
 			    ' EXTRACT(day FROM \1)',
 			    $res);
@@ -585,8 +584,11 @@ function spip_pg_frommysql($arg)
 			    $res);
 
 	$res = preg_replace("/(EXTRACT[(][^ ]* FROM *)\"([^\"]*)\"/", '\1\'\2\'', $res);
-	$res = preg_replace('/DATE_FORMAT\s*[(]([^,]*),\s*\'%Y%m%d\'[)]/', 'to_number(to_char(\1, \'YYYYMMDD\'), \'8\')', $res);
-	$res = preg_replace('/DATE_FORMAT\s*[(]([^,]*),\s*\'%Y%m\'[)]/', 'to_number(to_char(\1, \'YYYYMM\'),\'6\')', $res);
+
+	$res = preg_replace('/DATE_FORMAT\s*[(]([^,]*),\s*\'%Y%m%d\'[)]/', 'to_char(\1, \'YYYYMMDD\')', $res);
+
+	$res = preg_replace('/DATE_FORMAT\s*[(]([^,]*),\s*\'%Y%m\'[)]/', 'to_char(\1, \'YYYYMM\')', $res);
+
 	$res = preg_replace('/DATE_SUB\s*[(]([^,]*),/', '(\1 -', $res);
 	$res = preg_replace('/DATE_ADD\s*[(]([^,]*),/', '(\1 +', $res);
 	$res = preg_replace('/INTERVAL\s+(\d+\s+\w+)/', 'INTERVAL \'\1\'', $res);
@@ -601,7 +603,7 @@ function spip_pg_frommysql($arg)
 # correct en theorie mais produit des debordements arithmetiques
 #	$res = preg_replace("/(EXTRACT[(][^ ]* FROM *)(timestamp *'[^']*' *[+-] *timestamp *'[^']*') *[)]/", '\2', $res);
 	$res = preg_replace("/(EXTRACT[(][^ ]* FROM *)('[^']*')/", '\1 timestamp \2', $res);
-
+	$res = preg_replace("/\sLIKE\s+/", ' ILIKE ', $res);
 	return str_replace('REGEXP', '~', $res);
 }
 
@@ -730,7 +732,7 @@ function spip_pg_free($res, $serveur='',$requeter=true) {
 // http://doc.spip.org/@spip_pg_delete
 function spip_pg_delete($table, $where='', $serveur='',$requeter=true) {
 
-	$connexion = $GLOBALS['connexions'][$serveur ? $serveur : 0];
+	$connexion = &$GLOBALS['connexions'][$serveur ? strtolower($serveur) : 0];
 	$prefixe = $connexion['prefixe'];
 	$link = $connexion['link'];
 	$db = $connexion['db'];
@@ -751,7 +753,7 @@ function spip_pg_delete($table, $where='', $serveur='',$requeter=true) {
 
 // http://doc.spip.org/@spip_pg_insert
 function spip_pg_insert($table, $champs, $valeurs, $desc=array(), $serveur='',$requeter=true) {
-	$connexion = &$GLOBALS['connexions'][$serveur ? $serveur : 0];
+	$connexion = &$GLOBALS['connexions'][$serveur ? strtolower($serveur) : 0];
 	$prefixe = $connexion['prefixe'];
 	$link = $connexion['link'];
 	$db = $connexion['db'];
@@ -767,7 +769,12 @@ function spip_pg_insert($table, $champs, $valeurs, $desc=array(), $serveur='',$r
 	$ins = (strlen($champs)<3)
 	  ? " DEFAULT VALUES"
 	  : "$champs VALUES $valeurs";
-	$connexion['last'] = $q ="INSERT INTO $table $ins $ret";
+	  
+	$q ="INSERT INTO $table $ins $ret";
+	if (!$requeter) return $q;
+	$connexion['last'] = $q;
+	
+	
 	$r = spip_pg_query_simple($link, $q);
 #	spip_log($q);
 	if ($r) {
@@ -829,7 +836,7 @@ function spip_pg_insertq_multi($table, $tab_couples=array(), $desc=array(), $ser
 function spip_pg_update($table, $couples, $where='', $desc='', $serveur='',$requeter=true) {
 
 	if (!$couples) return;
-	$connexion = $GLOBALS['connexions'][$serveur ? $serveur : 0];
+	$connexion = $GLOBALS['connexions'][$serveur ? strtolower($serveur) : 0];
 	$prefixe = $connexion['prefixe'];
 	$link = $connexion['link'];
 	$db = $connexion['db'];
@@ -871,7 +878,7 @@ function spip_pg_updateq($table, $couples, $where='', $desc=array(), $serveur=''
 // http://doc.spip.org/@spip_pg_replace
 function spip_pg_replace($table, $values, $desc, $serveur='',$requeter=true) {
 	if (!$values) {spip_log("replace vide $table"); return 0;}
-	$connexion = &$GLOBALS['connexions'][$serveur ? $serveur : 0];
+	$connexion = &$GLOBALS['connexions'][$serveur ? strtolower($serveur) : 0];
 	$prefixe = $connexion['prefixe'];
 	$link = $connexion['link'];
 	$db = $connexion['db'];
@@ -972,8 +979,11 @@ function spip_pg_cite($v, $t)
 		if (strpos("0123456789", $v[0]) === false)
 			return spip_pg_frommysql($v);
 		else {
-			if (strpos($v, "-00-00") === 4)
-				$v = substr($v,0,4)."-01-01".substr($v,10);
+			if (strpos($v, "-00-00") <= 4) {
+				$annee = substr($v,0,4);
+				if (!intval($annee)) $annee = '0001';
+				$v = $annee ."-01-01".substr($v,10);
+			}
 			return "timestamp '$v'";
 		}
 	}
@@ -1040,11 +1050,14 @@ function spip_pg_in($val, $valeurs, $not='', $serveur) {
 }
 
 // http://doc.spip.org/@spip_pg_error
-function spip_pg_error($serveur) {
-	$connexion = $GLOBALS['connexions'][$serveur ? $serveur : 0];
-	$link = $connexion['link'];
+function spip_pg_error($query='', $serveur, $requeter=true) {
+	$link = $GLOBALS['connexions'][$serveur ? strtolower($serveur) : 0]['link'];
 	$s = $link ? pg_last_error($link) : pg_last_error();
-	return str_replace('ERROR', 'errcode: 1000 ', $s);
+	if ($s) {
+		$s = str_replace('ERROR', 'errcode: 1000 ', $s);
+		spip_log("$s - $query", 'pg.'._LOG_ERREUR);
+	}
+	return $s;
 }
 
 // http://doc.spip.org/@spip_pg_errno
@@ -1073,16 +1086,16 @@ function spip_pg_drop_view($view, $exist='', $serveur='',$requeter=true) {
 // http://doc.spip.org/@spip_pg_showbase
 function spip_pg_showbase($match, $serveur='',$requeter=true)
 {
-	$connexion = &$GLOBALS['connexions'][$serveur ? $serveur : 0];
+	$connexion = &$GLOBALS['connexions'][$serveur ? strtolower($serveur) : 0];
 	$link = $connexion['link'];
-	$connexion['last'] = $q = "SELECT tablename FROM pg_tables WHERE tablename ILIKE '$match'";
+	$connexion['last'] = $q = "SELECT tablename FROM pg_tables WHERE tablename ILIKE "._q($match);
 	return spip_pg_query_simple($link, $q);
 }
 
 // http://doc.spip.org/@spip_pg_showtable
 function spip_pg_showtable($nom_table, $serveur='',$requeter=true)
 {
-	$connexion = &$GLOBALS['connexions'][$serveur ? $serveur : 0];
+	$connexion = &$GLOBALS['connexions'][$serveur ? strtolower($serveur) : 0];
 	$link = $connexion['link'];
 	$connexion['last'] = $q = "SELECT column_name, column_default, data_type FROM information_schema.columns WHERE table_name ILIKE " . _q($nom_table);
 
@@ -1117,7 +1130,7 @@ function spip_pg_showtable($nom_table, $serveur='',$requeter=true)
 // http://doc.spip.org/@spip_pg_create
 function spip_pg_create($nom, $champs, $cles, $autoinc=false, $temporary=false, $serveur='',$requeter=true) {
 
-	$connexion = $GLOBALS['connexions'][$serveur ? $serveur : 0];
+	$connexion = $GLOBALS['connexions'][$serveur ? strtolower($serveur) : 0];
 	$prefixe = $connexion['prefixe'];
 	$link = $connexion['link'];
 	$db = $connexion['db'];
