@@ -3,13 +3,15 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2010                                                *
+ *  Copyright (c) 2001-2011                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
+if (!defined('_ECRIRE_INC_VERSION')) return;
+
 // infos :
 // il ne faut pas avoir de PDO::CONSTANTE dans ce fichier sinon php4 se tue !
 // idem, il ne faut pas de $obj->toto()->toto sinon php4 se tue !
@@ -182,8 +184,17 @@ function spip_sqlite_alter($query, $serveur='',$requeter=true){
 		$cle = strtoupper($matches[1]);
 		$colonne_origine = $matches[2];
 		$colonne_destination = '';
+
 		$def = $matches[3];
-		$def = _sqlite_remplacements_definitions_table($def);
+
+		// eluder une eventuelle clause before|after|first inutilisable
+		$defr = rtrim(preg_replace('/(BEFORE|AFTER|FIRST)(.*)$/is','', $def));
+		// remplacer les definitions venant de mysql
+		$defr = _sqlite_remplacements_definitions_table($defr);
+
+		// reinjecter dans le do
+		$do = str_replace($def,$defr,$do);
+		$def = $defr;
 		
 		switch($cle){
 			// suppression d'un index
@@ -307,10 +318,6 @@ function spip_sqlite_alter($query, $serveur='',$requeter=true){
 					$do = "ADD".substr($do, 10);
 			case 'ADD':
 			default:
-				if (preg_match('/^(.*)(BEFORE|AFTER|FIRST)(.*)$/is', $do, $matches)) {
-					$do = $matches[1];
-				}
-				
 				if (_sqlite_is_version(3, '', $serveur)){
 					$requete = new sqlite_traiter_requete("$debut $do", $serveur);
 					if (!$requete->executer_requete()){
@@ -374,7 +381,7 @@ function spip_sqlite_create($nom, $champs, $cles, $autoinc=false, $temporary=fal
 function spip_sqlite_create_base($nom, $serveur='', $option=true) {
 	$f = _DIR_DB . $nom . '.sqlite';
 	if (_sqlite_is_version(2, '', $serveur)) {
-		$ok = new sqlite_open($f, _SQLITE_CHMOD, $err);
+		$ok = sqlite_open($f, _SQLITE_CHMOD, $err);
 	} else {
 		$ok = new PDO("sqlite:$f");
 	}
@@ -460,27 +467,40 @@ function spip_sqlite_count($r, $serveur='',$requeter=true) {
 // http://doc.spip.org/@spip_sqlite_countsel
 function spip_sqlite_countsel($from = array(), $where = array(), $groupby = '', $having = array(), $serveur='',$requeter=true) {
 	$c = !$groupby ? '*' : ('DISTINCT ' . (is_string($groupby) ? $groupby : join(',', $groupby)));
-	$r = spip_sqlite_select("COUNT($c)", $from, $where,'', '', $limit,
-			$having, $serveur, $requeter);
+	$r = spip_sqlite_select("COUNT($c)", $from, $where,'', '', '',$having, $serveur, $requeter);
 	if ((is_resource($r) or is_object($r)) && $requeter) { // ressource : sqlite2, object : sqlite3
 		if (_sqlite_is_version(3,'',$serveur)){
-			list($r) = spip_sqlite_fetch($r, SPIP_SQLITE3_NUM, $serveur);
+			list($n) = spip_sqlite_fetch($r, SPIP_SQLITE3_NUM, $serveur);
 		} else {
-			list($r) = spip_sqlite_fetch($r, SPIP_SQLITE2_NUM, $serveur);
+			list($n) = spip_sqlite_fetch($r, SPIP_SQLITE2_NUM, $serveur);
 		}
-		
+		spip_sqlite_free($r,$serveur);
 	}
-	return $r;
+	return $n;
 }
 
 
 
 // http://doc.spip.org/@spip_sqlite_delete
 function spip_sqlite_delete($table, $where='', $serveur='',$requeter=true) {
-	return spip_sqlite_query(
+	$res = spip_sqlite_query(
 			  _sqlite_calculer_expression('DELETE FROM', $table, ',')
 			. _sqlite_calculer_expression('WHERE', $where),
 			$serveur, $requeter);
+
+	// renvoyer la requete inerte si demandee
+	if (!$requeter) return $res;
+	
+  if ($res){
+	  $link  = _sqlite_link($serveur);
+	  if (_sqlite_is_version(3, $link)) {
+		  return $res->rowCount();
+	  } else {
+		  return sqlite_changes($link);
+	  }
+  }
+  else
+	  return false;
 }
 
 
@@ -554,7 +574,7 @@ function spip_sqlite_drop_index($nom, $table, $serveur='', $requeter=true) {
  * @return string erreur eventuelle
 **/
 // http://doc.spip.org/@spip_sqlite_error
-function spip_sqlite_error($serveur='') {
+function spip_sqlite_error($query='', $serveur='') {
 	$link  = _sqlite_link($serveur);
 	
 	if (_sqlite_is_version(3, $link)) {
@@ -683,7 +703,7 @@ function spip_sqlite_get_charset($charset=array(), $serveur='',$requeter=true){
 
 // http://doc.spip.org/@spip_sqlite_hex
 function spip_sqlite_hex($v){
-	return "0x" . $v;
+	return hexdec($v);
 }
 
 
@@ -723,16 +743,18 @@ function spip_sqlite_insert($table, $champs, $valeurs, $desc='', $serveur='',$re
 		$t = trace_query_start();
 	} else $t = 0 ;
  
-	$query="INSERT OR REPLACE INTO $table $champs VALUES $valeurs";
+	$query="INSERT INTO $table ".($champs?"$champs VALUES $valeurs":"DEFAULT VALUES");
 	
 	
-	if ($r = spip_sqlite_query($query, $serveur)) {
-		if (!$requeter) return $query;
+	if ($r = spip_sqlite_query($query, $serveur, $requeter)) {
+		if (!$requeter) return $r;
 		
 		if (_sqlite_is_version(3, $sqlite)) $nb = $sqlite->lastInsertId();
 		else $nb = sqlite_last_insert_rowid($sqlite);
 	} else $nb = 0;
-	return $t ? trace_query_end($query, $t, $nb, $serveur) : $nb;
+
+	$err = spip_sqlite_error($query, $serveur);
+	return $t ? trace_query_end($query, $t, $nb, $err, $serveur) : $nb;
 
 }
 
@@ -746,11 +768,19 @@ function spip_sqlite_insertq($table, $couples=array(), $desc=array(), $serveur='
 	foreach ($couples as $champ => $val) {
 		$couples[$champ]= _sqlite_calculer_cite($val, $fields[$champ]);
 	}
-	
+
 	// recherche de champs 'timestamp' pour mise a jour auto de ceux-ci
 	$couples = _sqlite_ajouter_champs_timestamp($table, $couples, $desc, $serveur);
+
+	// si aucun champ donne pour l'insertion, on en cherche un avec un DEFAULT
+	// sinon sqlite3 ne veut pas inserer
+	$cles = $valeurs = "";
+	if (count($couples)) {
+		$cles = "(".join(',',array_keys($couples)).")";
+		$valeurs = "(".join(',', $couples).")";
+	}
 	
-	return spip_sqlite_insert($table, "(".join(',',array_keys($couples)).")", "(".join(',', $couples).")", $desc, $serveur, $requeter);
+	return spip_sqlite_insert($table, $cles , $valeurs , $desc, $serveur, $requeter);
 }
 
 
@@ -822,9 +852,10 @@ function spip_sqlite_optimize($table, $serveur='', $requeter=true) {
 
 // avoir le meme comportement que _q()
 function spip_sqlite_quote($v, $type=''){
-	if (is_int($v)) return strval($v);
-	if ($type === 'int' AND !$v) return '0';
 	if (is_array($v)) return join(",", array_map('spip_sqlite_quote', $v));
+	if (is_int($v)) return strval($v);
+	if (strncmp($v,'0x',2)==0 AND ctype_xdigit(substr($v,2))) return hexdec(substr($v,2));
+	if ($type === 'int' AND !$v) return '0';
 
 	if (function_exists('sqlite_escape_string')) {
 		return "'" . sqlite_escape_string($v) . "'";
@@ -940,7 +971,19 @@ function spip_sqlite_set_charset($charset, $serveur='',$requeter=true){
 
 // http://doc.spip.org/@spip_sqlite_showbase
 function spip_sqlite_showbase($match, $serveur='',$requeter=true){
-	return spip_sqlite_query('SELECT name FROM sqlite_master WHERE type LIKE "'.$match.'"', $serveur, $requeter);
+	// type est le type d'entrée : table / index / view
+	// on ne retourne que les tables (?) et non les vues...
+	# ESCAPE non supporte par les versions sqlite <3
+	#	return spip_sqlite_query("SELECT name FROM sqlite_master WHERE type='table' AND tbl_name LIKE "._q($match)." ESCAPE '\'", $serveur, $requeter);
+	$match = preg_quote($match);
+	$match = str_replace("\\\_","[[TIRETBAS]]",$match);
+	$match = str_replace("\\\%","[[POURCENT]]",$match);
+	$match = str_replace("_",".",$match);
+	$match = str_replace("%",".*",$match);
+	$match = str_replace("[[TIRETBAS]]","_",$match);
+	$match = str_replace("[[POURCENT]]","%",$match);
+	$match = "^$match$";
+	return spip_sqlite_query("SELECT name FROM sqlite_master WHERE type='table' AND tbl_name REGEXP "._q($match), $serveur, $requeter);
 }
 
 
@@ -978,14 +1021,17 @@ function spip_sqlite_showtable($nom_table, $serveur='',$requeter=true){
 			$fields = array();
 			foreach (explode(",",$dec) as $v) {
 				preg_match("/^\s*([^\s]+)\s+(.*)/",$v,$r);
-				$fields[strtolower($r[1])] = $r[2];
+				// trim car 'Sqlite Manager' (plugin Firefox) utilise des guillemets
+				// lorsqu'on modifie une table avec cet outil.
+				// possible que d'autres fassent de meme.
+				$fields[ trim(strtolower($r[1]),'"') ] = $r[2];
 			}
 			// key inclues dans la requete
 			$keys = array();
 			foreach(preg_split('/\)\s*,?/',$namedkeys) as $v) {
 				if (preg_match("/^\s*([^(]*)\((.*)$/",$v,$r)) {
 					$k = str_replace("`", '', trim($r[1]));
-					$t = strtolower(str_replace("`", '', $r[2]));
+					$t = trim(strtolower(str_replace("`", '', $r[2])), '"');
 					if ($k && !isset($keys[$k])) $keys[$k] = $t; else $keys[] = $t;
 				}
 			}
@@ -1121,14 +1167,16 @@ function _sqlite_link($serveur = '', $recharger = false){
 // renvoie les bons echappements (pas sur les fonctions now())
 // http://doc.spip.org/@_sqlite_calculer_cite
 function _sqlite_calculer_cite($v, $type) {
-	if (sql_test_date($type) AND preg_match('/^\w+\(/', $v)
-	OR (sql_test_int($type)
-		 AND (is_numeric($v)
-		      OR (ctype_xdigit(substr($v,2))
-			  AND $v[0]=='0' AND $v[1]=='x'))))
+	if (sql_test_date($type) AND preg_match('/^\w+\(/', $v))
 		return $v;
+	if (sql_test_int($type)) {
+		if (is_numeric($v))
+			return $v;
+		if (ctype_xdigit(substr($v,2)) AND strncmp($v,'0x',2)==0)
+			return hexdec(substr($v,2));
+	}
 	//else return  ("'" . spip_sqlite_quote($v) . "'");
-	else return  (spip_sqlite_quote($v));
+	return  (spip_sqlite_quote($v));
 }
 
 
@@ -1460,19 +1508,26 @@ function _sqlite_ref_fonctions(){
 
 // $query est une requete ou une liste de champs
 // http://doc.spip.org/@_sqlite_remplacements_definitions_table
-function _sqlite_remplacements_definitions_table($query){
+function _sqlite_remplacements_definitions_table($query,$autoinc=false){
 	// quelques remplacements
 	$num = "(\s*\([0-9]*\))?";
 	$enum = "(\s*\([^\)]*\))?";
 	
 	$remplace = array(
-		// pour l'autoincrement, il faut des INTEGER NOT NULL PRIMARY KEY
-		'/(big|small|medium|tiny)?int(eger)?'.$num.'/is' => 'INTEGER',		
 		'/enum'.$enum.'/is' => 'VARCHAR',
 		'/binary/is' => '',
+		'/COLLATE \w+_bin/is' => '',
 		'/auto_increment/is' => '',
+		'/(timestamp .* )ON .*$/is' => '\\1',
+		'/character set \w+/is' => '',
+		'/((big|small|medium|tiny)?int(eger)?)'.$num.'\s*unsigned/is' => '\\1 UNSIGNED',
+		'/(text\s+not\s+null)\s*$/is' => "\\1 DEFAULT ''",
 	);
 
+	// pour l'autoincrement, il faut des INTEGER NOT NULL PRIMARY KEY
+	if ($autoinc)
+		$remplace['/(big|small|medium|tiny)?int(eger)?'.$num.'/is'] = 'INTEGER';
+
 	return preg_replace(array_keys($remplace), $remplace, $query);
 }
 
@@ -1506,7 +1561,7 @@ function _sqlite_requete_create($nom, $champs, $cles, $autoinc=false, $temporary
 	}
 	if ($c) $keys = "\n\t\t$pk ($c)";
 	
-	$champs = _sqlite_remplacements_definitions_table($champs);
+	$champs = _sqlite_remplacements_definitions_table($champs, $autoinc);
 	foreach($champs as $k => $v) {
 		$query .= "$s\n\t\t$k $v";
 		$s = ",";
@@ -1551,7 +1606,7 @@ function _sqlite_ajouter_champs_timestamp($table, $couples, $desc='', $serveur='
 			$f = charger_fonction('trouver_table', 'base');
 			$desc = $f($table, $serveur);
 			// si pas de description, on ne fait rien, ou on die() ?
-			if (!$desc) return $couples;
+			if (!$desc OR !$desc['field']) return $couples;
 		}
 		
 		// recherche des champs avec simplement 'TIMESTAMP'
@@ -1618,7 +1673,7 @@ class sqlite_traiter_requete{
 // http://doc.spip.org/@sqlite_traiter_requete
 	function sqlite_traiter_requete($query, $serveur = ''){
 		$this->query = $query;
-		$this->serveur = $serveur;
+		$this->serveur = strtolower($serveur);
 		
 		if (!($this->link = _sqlite_link($this->serveur)) && (!defined('_ECRIRE_INSTALL') || !_ECRIRE_INSTALL)){
 			spip_log("Aucune connexion sqlite (link)");
@@ -1639,6 +1694,7 @@ class sqlite_traiter_requete{
 	// faire le tracage si demande 
 // http://doc.spip.org/@executer_requete
 	function executer_requete(){
+		$err = "";
 		if ($this->tracer) {
 			include_spip('public/tracer');
 			$t = trace_query_start();
@@ -1646,6 +1702,8 @@ class sqlite_traiter_requete{
  
 # spip_log("requete: $this->serveur >> $this->query",'query'); // boum ? pourquoi ?
 		if ($this->link){
+			// memoriser la derniere erreur PHP vue
+			$e = error_get_last();
 			// sauver la derniere requete
 			$GLOBALS['connexions'][$this->serveur ? $this->serveur : 0]['last'] = $this->query;
 			
@@ -1670,11 +1728,21 @@ class sqlite_traiter_requete{
 			} else {
 				$r = sqlite_query($this->link, $this->query);
 			}
+
+			// loger les warnings/erreurs eventuels de sqlite remontant dans PHP
+			if ($err = error_get_last() AND $err!=$e) {
+				$err = strip_tags($err['message'])." in ".$err['file']." line ".$err['line'];
+				spip_log("$err - ".$this->query, 'sqlite');
+			}
+		  else $err="";
+
 		} else {
 			$r = false;	
 		}
 
-		return $t ? trace_query_end($this->query, $t, $r, $serveur) : $r;
+		if (spip_sqlite_errno($serveur))
+			$err .= spip_sqlite_error($this->query, $serveur);
+		return $t ? trace_query_end($this->query, $t, $r, $err, $serveur) : $r;
 	}
 		
 	// transformer la requete pour sqlite 
