@@ -3,14 +3,14 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2010                                                *
+ *  Copyright (c) 2001-2011                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined("_ECRIRE_INC_VERSION")) return; // securiser
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 define('URLS_ARBO_EXEMPLE', '/article/titre');
 
@@ -147,8 +147,8 @@ function urls_arbo_creer_chaine_url($x) {
 	$url_old = $x['data'];
 	$objet = $x['objet'];
 	include_spip('inc/filtres');
-	@define('_URLS_ARBO_MAX', 35);
-	@define('_URLS_ARBO_MIN', 3);
+	if (!defined('_URLS_ARBO_MAX')) define('_URLS_ARBO_MAX', 35);
+	if (!defined('_URLS_ARBO_MIN')) define('_URLS_ARBO_MIN', 3);
 
 	include_spip('action/editer_url');
 	if (!$url = url_nettoyer($objet['titre'],_URLS_ARBO_MAX,_URLS_ARBO_MIN,'-',_url_arbo_minuscules?'strtolower':''))
@@ -189,12 +189,15 @@ function declarer_url_arbo($type, $id_objet) {
 	if (!isset($urls[$type][$id_objet]) OR $modifier_url) {
 		$trouver_table = charger_fonction('trouver_table', 'base');
 		$desc = $trouver_table(table_objet($type));
-		$table = $desc['table'];
+		$champ_titre = $desc['titre'];
 		$col_id =  @$desc['key']["PRIMARY KEY"];
-		if (!$col_id) return false; // Quand $type ne reference pas une table
+		//  $type doit designer une table, avec champ indiquant un titre
+		if (!$col_id OR !$champ_titre) return false; 
+
+		$table = $desc['table'];
 		$id_objet = intval($id_objet);
 	
-		$champ_titre = $desc['titre'] ? $desc['titre'] : 'titre';
+
 		// parent
 		$champ_parent = url_arbo_parent($type);
 		$sel_parent = ($champ_parent)?", O.".reset($champ_parent).' as parent':'';
@@ -273,8 +276,10 @@ function declarer_url_arbo($type, $id_objet) {
 // http://doc.spip.org/@_generer_url_arbo
 function _generer_url_arbo($type, $id, $args='', $ancre='') {
 
-	if ($generer_url_externe = charger_fonction("generer_url_$type",'urls',true))
-		return $generer_url_externe($id, $args, $ancre);
+	if ($generer_url_externe = charger_fonction("generer_url_$type",'urls',true)) {
+		$url = $generer_url_externe($id, $args, $ancre);
+		if (NULL != $url) return $url;
+	}
 
 	if ($type == 'document') {
 		include_spip('inc/documents');
