@@ -3,14 +3,14 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2010                                                *
+ *  Copyright (c) 2001-2011                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined("_ECRIRE_INC_VERSION")) return; // securiser
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 define('URLS_PAGE_EXEMPLE', 'spip.php?article12');
 
@@ -28,8 +28,10 @@ define ('_debut_urls_page', get_spip_script('./').'?');
 // http://doc.spip.org/@_generer_url_page
 function _generer_url_page($type,$id, $args='', $ancre='') {
 
-	if ($generer_url_externe = charger_fonction("generer_url_$type",'urls',true))
-		return $generer_url_externe($id, $args, $ancre);
+	if ($generer_url_externe = charger_fonction("generer_url_$type",'urls',true)) {
+		$url = $generer_url_externe($id, $args, $ancre);
+		if (NULL != $url) return $url;
+	}
 
 	if ($type == 'document') {
 		include_spip('inc/documents');
