@@ -1,5 +1,17 @@
 <?php
 
+/***************************************************************************\
+ *  SPIP, Systeme de publication pour l'internet                           *
+ *                                                                         *
+ *  Copyright (c) 2001-2011                                                *
+ *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
+ *                                                                         *
+ *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
+ *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
+\***************************************************************************/
+
+if (!defined('_ECRIRE_INC_VERSION')) return;
+
 include_spip('inc/actions');
 include_spip('inc/editer');
 
@@ -18,6 +30,15 @@ function formulaires_editer_auteur_charger_dist($id_auteur='new', $retour='', $l
 	return $valeurs;
 }
 
+/**
+ * Identifier le formulaire en faisant abstraction des parametres qui
+ * ne representent pas l'objet edite
+ */
+function formulaires_editer_auteur_identifier_dist($id_auteur='new', $retour='', $lier_id_article=0, $config_fonc='auteurs_edit_config', $row=array(), $hidden=''){
+	return serialize(array($id_auteur,$lier_id_article));
+}
+
+
 // Choix par defaut des options de presentation
 // http://doc.spip.org/@articles_edit_config
 function auteurs_edit_config($row)
