@@ -3,20 +3,22 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2010                                                *
+ *  Copyright (c) 2001-2011                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined("_ECRIRE_INC_VERSION")) return;	#securite
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 include_spip('base/abstract_sql');
 
 function is_url_prive($cible){
-	$parse = parse_url($cible);
-	return strncmp(substr($parse['path'],-strlen(_DIR_RESTREINT_ABS)), _DIR_RESTREINT_ABS, strlen(_DIR_RESTREINT_ABS))==0;
+	include_spip('inc/filtres_mini');
+	$path = parse_url(tester_url_absolue($cible)?$cible:url_absolue($cible));
+	$path = (isset($path['path'])?$path['path']:'');
+	return strncmp(substr($path,-strlen(_DIR_RESTREINT_ABS)), _DIR_RESTREINT_ABS, strlen(_DIR_RESTREINT_ABS))==0;
 }
 
 function formulaires_login_charger_dist($cible="",$login="",$prive=null)
@@ -73,10 +75,12 @@ function formulaires_login_charger_dist($cible="",$login="",$prive=null)
 
 		if ($res['redirect']){
 			include_spip('inc/headers');
+			# preparer un lien pour quand redirige_formulaire ne fonctionne pas
+			$valeurs['_deja_loge'] = inserer_attribut(
+				"<a>" . _T('login_par_ici') . "</a>$m",
+				'href', $res['redirect']
+			);
 			$m = redirige_formulaire($res['redirect']);
-			# quand la redirection 302 ci-dessus ne fonctionne pas
-			$valeurs['_deja_loge'] =
-			"<a href='$cible'>" . _T('login_par_ici') . "</a>$m";
 		}
 	}
 	// en cas d'echec de cookie, inc_auth a renvoye vers le script de
@@ -121,9 +125,7 @@ function formulaires_login_verifier_dist($cible="",$login="",$prive=null){
 
 	if (!$session_login) {
 		# pas de login saisi !
-		return array('message_erreur' =>
-			_T('login_identifiant_inconnu',
-				array('login' => htmlspecialchars($login))));
+		return array('var_login' => _T('info_obligatoire'));
 	}
 
 	// appeler auth_identifier_login qui va :
@@ -185,14 +187,21 @@ function formulaires_login_traiter_dist($cible="",$login="",$prive=null){
 
 	if ($cible) {
 		$cible = parametre_url($cible, 'var_login', '', '&');
-	} 
-	
-	// transformer la cible absolue en cible relative
-	// pour pas echouer quand la meta adresse_site est foireuse
-	if (strncmp($cible,$u = url_de_base(),strlen($u))==0){
-		$cible = "./".substr($cible,strlen($u));
+
+		// transformer la cible absolue en cible relative
+		// pour pas echouer quand la meta adresse_site est foireuse
+		if (strncmp($cible,$u = url_de_base(),strlen($u))==0){
+			$cible = "./".substr($cible,strlen($u));
+		}
+
+		// si c'est une url absolue, refuser la redirection
+		// sauf si cette securite est levee volontairement par le webmestre
+		elseif (tester_url_absolue($cible) AND !defined('_AUTORISER_LOGIN_ABS_REDIRECT')) {
+			$cible = "";
+		}
 	}
 
+
 	// Si on est admin, poser le cookie de correspondance
 	if ($GLOBALS['auteur_session']['statut'] == '0minirezo') {
 		include_spip('inc/cookie');
@@ -206,12 +215,13 @@ function formulaires_login_traiter_dist($cible="",$login="",$prive=null){
 			include_spip('inc/headers');
 			$res['redirect'] = $cible;
 		} else {
-			$res['message_ok'] .= "<a href='$cible'>" .
-			  _T('login_par_ici') .
-			  "</a>";
+			$res['message_ok'] .= inserer_attribut(
+				"<a>" . _T('login_par_ici') . "</a>",
+				'href', $cible
+			);
 		}
 	}
 	return $res;
 }
 
-?>
\ No newline at end of file
+?>
