@@ -3,13 +3,15 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2010                                                *
+ *  Copyright (c) 2001-2011                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
+if (!defined('_ECRIRE_INC_VERSION')) return;
+
 // Filtre ad hoc pour le formulaire de login:
 // le parametre var_login n'est pas dans le contexte pour optimiser le cache
 // il faut aller le chercher a la main
@@ -24,16 +26,18 @@ function informer_auteur($bof)
 		unset($row['id_auteur']);
 	else {
 		// piocher les infos sur un autre login
-		$n = sql_countsel('spip_auteurs',"login<>''");
-		$n = (abs(crc32($login))%$n);
-		$row = auth_informer_login(sql_getfetsel('login','spip_auteurs',"login<>''",'','',"$n,1"));
-		if ($row AND is_array($row)){
-			unset($row['id_auteur']);
-			$row['login'] = $login;
+		if ($n = sql_countsel('spip_auteurs',"login<>''")){
+			$n = (abs(crc32($login))%$n);
+			$row = auth_informer_login(sql_getfetsel('login','spip_auteurs',"login<>''",'','',"$n,1"));
+			if ($row AND is_array($row)){
+				unset($row['id_auteur']);
+				$row['login'] = $login;
+			}
 		}
+		else $row = array();
 	}
 
 	return json_export($row);
 }
 
-?>
\ No newline at end of file
+?>
