@@ -3,14 +3,14 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2010                                                *
+ *  Copyright (c) 2001-2011                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 function formulaires_inscription_charger_dist($mode, $focus, $id=0) {
 	$valeurs = array('nom_inscription'=>'','mail_inscription'=>'', 'id'=>$id);
@@ -190,7 +190,7 @@ function test_login($nom, $mail) {
 	// il faut eviter que le login soit vraiment trop court
 	if (strlen($login_base) < 3) {
 		$mail = strtolower(translitteration(preg_replace('/@.*/', '', $mail)));
-		$login_base = preg_replace("/[^\w\d]/", "_", $nom);
+		$login_base = preg_replace("/[^\w\d]/", "_", $mail);
 	}
 	if (strlen($login_base) < 3)
 		$login_base = 'user';
